@@ -49,7 +49,7 @@
  *					  and Luis Miguel Silveira, MIT RLE.
  */
 
-//#define DEBUG 0
+//#define DEBUG_RENDER 0
 
 #include <stdlib.h>
 #include <string.h>
@@ -58,6 +58,7 @@
 #include "glyph.h"
 #include "oconfig.h"
 #include "dvi.h"
+#include "fontpool.h"
 
 #include <kdebug.h>
 #include <kprocess.h>
@@ -222,24 +223,6 @@ void dviWindow::set_empty_char(unsigned int cmd, unsigned int ch)
   return;
 }
 
-
-void dviWindow::load_n_set_char(unsigned int cmd, unsigned int ch)
-{
-#ifdef DEBUG_RENDER
-  kdDebug() << "load_n_set_char" << endl;
-#endif
-
-  if ( currinf.fontp->load_font() ) {	/* if not found */
-    kdError() << "Character(s) will be left blank." << endl;
-    currinf.set_char_p = currinf.fontp->set_char_p = &dviWindow::set_empty_char;
-    return;
-  }
-  currinf.set_char_p = currinf.fontp->set_char_p;
-  (this->*currinf.set_char_p)(cmd, ch);
-  return;
-}
-
-
 void dviWindow::set_vf_char(unsigned int cmd, unsigned int ch)
 {
 #ifdef DEBUG_RENDER
@@ -520,20 +503,29 @@ void dviWindow::draw_part(struct frame *minframe, double current_dimconv)
 
 void dviWindow::draw_page(void)
 {
+  // Check if all the fonts are loaded. If that is not the case, we
+  // return and do not draw anything. The font_pool will later emit
+  // the signal "fonts_are_loaded" and thus trigger a redraw of the
+  // page.
+  if (font_pool->check_if_fonts_are_loaded() == -1)
+    return;
+
+  // Print debugging information @@@ - remove later
+  font_pool->status();
+
 #ifdef DEBUG_RENDER
   kdDebug() <<"draw_page" << endl;
 #endif
 
   // Render the PostScript background, if there is one.
+    foreGroundPaint.fillRect(pixmap->rect(), Qt::white );
   if (_postscript) {
     QPixmap *pxm = PS_interface->graphics(current_page);
     if (pxm != NULL) {
       foreGroundPaint.drawPixmap(0, 0, *pxm);
       delete pxm;
-    } else
-      foreGroundPaint.fillRect(pixmap->rect(), Qt::white );
-  } else
-    foreGroundPaint.fillRect(pixmap->rect(), Qt::white );
+    }
+  }
   
   // Step 4: Now really write the text
   (void) lseek(fileno(dviFile->file), dviFile->page_offset[current_page], SEEK_SET);
