@@ -1,6 +1,6 @@
    /*
 
-    $Id: kfax.cpp,v 1.53 2000/10/09 21:10:11 faure Exp $
+    $Id: kfax.cpp,v 1.57 2001/01/25 13:49:17 mlaurent Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -46,11 +46,12 @@
 #include <kmessagebox.h>
 #include <kcmdlineargs.h>
 #include <kio/netaccess.h>
+#include <knotifyclient.h>
+#include <ktempfile.h>
 
 #include "kfax.h"
 #include "kfax.moc"
 #include "version.h"
-#include "urldlg.h"
 #include "viewfax.h"
 
 #ifdef HAVE_PATHS_H
@@ -378,22 +379,13 @@ void TopLevel::setupMenuBar(){
   view =        new QPopupMenu ();
   options = 	new QPopupMenu ();
 
-
-  QString about = i18n("\nKFax %1\n\n"
-		     "Copyright 1997-98\n"
-                     "Bernd Johannes Wuebben\n"
-                     "wuebben@kde.org").arg(KFAXVERSION);
-
-  help = helpMenu(about);
+  help = helpMenu();
 
   help->insertItem (i18n("Help page"), 		this, 	SLOT(helpshort()));
 
   file->insertItem (i18n("&Open Fax..."),		this, 	SLOT(file_open()),KStdAccel::open());
   file->insertItem (i18n("&Add Fax..."),		this, 	SLOT(addFax()));
-  //  file->insertItem ("&Save As...",		this, 	SLOT(dummy()));
-  file->insertSeparator (-1);
-  file->insertItem (i18n("Open &URL..."),	this,	SLOT(file_open_url()));
-  file->insertItem (i18n("Save to U&RL..."),	this,	SLOT(file_save_url()));
+  file->insertItem (i18n("&Save Fax..."),		this, 	SLOT(file_save()));
   file->insertItem (i18n("&Close Fax"),		this,	SLOT(closeFax()),KStdAccel::close());
   file->insertSeparator (-1);
   file->insertItem (i18n("&Print..."),	this,	SLOT(print()),KStdAccel::print() );
@@ -527,47 +519,6 @@ void TopLevel::setupStatusBar(){
     //    statusBar()->setBorderWidth(1);
 }
 
-
-
-void TopLevel::file_open_url(){
-
-  UrlDlg l( this,i18n("Open Location:"), "ftp://localhost/welcome");
-
-  if ( l.exec() )
-    {
-      QString n = l.getText();
-      if ( n.left(5) != "file:" && n.left(4) == "ftp:" )
-	openNetFile( l.getText());
-      else
-	openNetFile( l.getText());
-    }
-
-}
-
-void TopLevel::file_save_url(){
-
-  if(!thispage || !thispage->pathname){
-    KMessageBox::sorry(this, i18n("You need to open a Fax first"));
-    return;
-  }
-
-  if(thispage && thispage->pathname){
-
-    UrlDlg l( this, i18n("Save to Location:"), thispage->pathname);
-
-    if ( l.exec() )
-      {
-	QString n = l.getText();
-	if ( n.left(5) != "file:" && n.left(4) == "ftp:" )
-	  saveNetFile( l.getText() );	
-	else		
-	  saveNetFile( l.getText() );
-      }
-  }
-}
-
-
-
 void TopLevel::quiteditor(){
 
   writeSettings();
@@ -575,92 +526,50 @@ void TopLevel::quiteditor(){
 
 }
 
-
-
-
-void TopLevel::file_close(){
-
-
-}
-
-void TopLevel::file_save(){
-
-
-}
-
-
-void TopLevel::file_open(){
-
-  QString newfile;
-
-  /*
-  QString d;
-  if ( !filename.isEmpty() )
-    d = QFileInfo( filename ).dirPath();
-  else
-    d = QDir::currentDirPath();
-    */
-
-
+void TopLevel::file_save()
+{
   KURL url = KFileDialog::getOpenURL(current_directory,"*");
 
-  if (newfile.isEmpty())
+  if (url.isEmpty())
     return;
 
-  if( !url.isLocalFile() )
+  if( url.isLocalFile() )
   {
-    KMessageBox::sorry( 0L, i18n( "Only local files are supported yet." ) );
-    return;
+    current_directory =  url.directory();
   }
 
-  newfile = url.path();
+  saveNetFile(url);  
+}
 
-  current_directory =  QFileInfo( newfile ).dirPath() ;
 
-  FreeFax();
+void TopLevel::file_open()
+{
+  KURL url = KFileDialog::getOpenURL(current_directory,"*");
 
-  fname = newfile;
+  if (url.isEmpty())
+    return;
 
-  (void) notetiff(fname.ascii());	
-
-  thispage = auxpage;
-
-  have_no_fax = false;
-  newPage();
-  resizeView();
-  putImage();
+  if( url.isLocalFile() )
+  {
+    current_directory = url.directory();
+  }
+  closeFax();
 
+  openNetFile(url);  
 }
 
 void TopLevel::addFax()
 {
-  /*
-  QString d;
-  if ( !filename.isEmpty() )
-    d = QFileInfo( filename ).dirPath();
-  else
-    d = QDir::currentDirPath();
-    */
-
-
   KURL url = KFileDialog::getOpenURL(current_directory,"*");
 
-  if( url.isEmpty() )
+  if (url.isEmpty())
     return;
 
-  if( !url.isLocalFile() )
+  if( url.isLocalFile() )
   {
-    KMessageBox::sorry( 0L, i18n( "Only local files are supported yet." ) );
-    return;
+    current_directory = url.directory();
   }
-
-  QString newfile = url.path();
-
-  current_directory =  QFileInfo( newfile ).dirPath() ;
-
-  fname = newfile;
-
-  openadd(fname);
+  openNetFile(url);  
 }
 
 
@@ -676,7 +585,7 @@ void TopLevel::openadd(QString filename){
 
   auxpage = lastpage;
 
-  (void) notetiff(filename.ascii());	
+  (void) notetiff(QFile::encodeName(filename));	
 
   if(!this_is_the_first_fax){
     if(auxpage->next)
@@ -692,58 +601,28 @@ void TopLevel::openadd(QString filename){
   newPage();
   resizeView();
   putImage();
-
 }
 
-/*
-QFileDialog* TopLevel::getFileDialog(const QString& captiontext){
-
-  if(!file_dialog){
-
-    file_dialog = new QFileDialog(current_directory,"*",this,"file_dialog",TRUE);
-  }
-
-  file_dialog->setCaption(captiontext);
-  file_dialog->rereadDir();
-
-  return file_dialog;
-}
-*/
-
-
 void TopLevel::setGeneralStatusField(QString text){
 
     statusbar_timer->stop();
     statusBar()->changeItem(text,ID_FNAME);
     statusbar_timer->start(10000,TRUE); // single shot
-
 }
 
 
-void TopLevel::file_save_as(){
-
-
-}
-
-
-
-
-void TopLevel::helpselected(){
-
+void TopLevel::helpselected()
+{
   kapp->invokeHelp( );
-
-
 }
 
-void TopLevel::helpshort(){
-
+void TopLevel::helpshort()
+{
   helptiff();
-
 }
 
-
-void TopLevel::toggleStatusBar(){
-
+void TopLevel::toggleStatusBar()
+{
   if(hide_statusbar) {
     hide_statusbar=FALSE;
     statusBar()->show();
@@ -756,7 +635,6 @@ void TopLevel::toggleStatusBar(){
     options->changeItem(i18n("Show &Status Bar"), statusID);
   }
   resizeView();
-
 }
 
 
@@ -772,22 +650,19 @@ void TopLevel::toggleToolBar(){
     options->changeItem(i18n("Hide &Tool Bar"), toolID);
   }
   else {
-
     hide_toolbar=TRUE;
     toolBar()->hide();
     options->changeItem(i18n("Show &Tool Bar"), toolID);
-
   }
 
   resizeView();
 }	
 
 
-void TopLevel::closeEvent( QCloseEvent *e ){
-
+void TopLevel::closeEvent( QCloseEvent *e )
+{
   (void) e;
 
-  file_close();
   writeSettings();
   kapp->quit();
 };
@@ -942,7 +817,7 @@ void TopLevel::printIt(){
   if(pi.lpr){
 
     psfile = NULL;
-    psfile = popen(pi.cmd.ascii(),"w");
+    psfile = popen(QFile::encodeName(pi.cmd),"w");
 
     if(psfile == NULL){
       QString str = i18n("Can't print to \"%1\"\n").arg(pi.cmd);
@@ -953,7 +828,7 @@ void TopLevel::printIt(){
   }
   else{
 
-    psfile = fopen(pi.file.ascii(),"w");
+    psfile = fopen(QFile::encodeName(pi.file),"w");
     if(psfile == NULL){
       QString str = i18n("Couldn't create %1\n").arg(pi.file);
       KMessageBox::error(this, str);
@@ -994,15 +869,11 @@ void TopLevel::printIt(){
       if(defaultpage.expander ==  g31expand)
 	faxtype = 31;
 
+      KTempFile tmpFile;
+      tmpFile.setAutoDelete(true);
 
-      QString tempfile;
-      tempfile = tmpnam(NULL);
-
-      fax2tiffmain(pn->pathname,tempfile.ascii(),pn->lsbfirst,pn->vres?0:1,faxtype);
-      fax2psmain(tempfile.ascii(),psfile,width,height,pi.scale);
-
-      remove(tempfile.ascii());
-
+      fax2tiffmain(pn->pathname,QFile::encodeName(tmpFile.name()),pn->lsbfirst,pn->vres?0:1,faxtype);
+      fax2psmain(QFile::encodeName(tmpFile.name()),psfile,width,height,pi.scale);
     }
 
   }
@@ -1037,12 +908,8 @@ void TopLevel::loading_slot(){
 }
 
 
-void TopLevel::saveNetFile( const QString& _url)
+void TopLevel::saveNetFile( const KURL& u)
 {
-
-    int res;
-    netFile = _url;
-    KURL u( netFile );
     if ( u.isMalformed() )
     {
 	KMessageBox::sorry(this, i18n("Malformed URL"));
@@ -1053,7 +920,7 @@ void TopLevel::saveNetFile( const QString& _url)
     if ( u.isLocalFile() )
       {
         saving_slot();
-	res = copyfile(u.path().ascii(),thispage->pathname);
+	int res = copyfile(QFile::encodeName(u.path()),thispage->pathname);
 	if (res==0) {
 	  KMessageBox::error(this, i18n("Failure in 'copy file()'\n"
 				"Couldn't save file!"));
@@ -1065,26 +932,21 @@ void TopLevel::saveNetFile( const QString& _url)
 	return;
       }
 
-    tmpFile = _PATH_TMP"/kfax" + time( 0L );
+    KTempFile tmpFile;
+    tmpFile.setAutoDelete(true);
 
-    res = copyfile(tmpFile.ascii(),thispage->pathname );
+    int res = copyfile(QFile::encodeName(tmpFile.name()),thispage->pathname );
     if (res==0) {
       KMessageBox::error(this, i18n("Failure in 'copy file()'\n"
 			    "Couldn't save file!"));
       return;
     }
 
-    KIO::NetAccess::upload( tmpFile, u );
-
-    QString string = i18n("Finished '%1'").arg(tmpFile);
-    unlink( tmpFile.local8Bit() );
+    KIO::NetAccess::upload( tmpFile.name(), u );
 }
 
-void TopLevel::openNetFile( const QString& _url)
+void TopLevel::openNetFile( const KURL &u)
 {
-
-  netFile = _url;
-  KURL u( netFile );
   if ( u.isMalformed() )
     {
 	KMessageBox::error(this, i18n("Malformed URL"));
@@ -1102,12 +964,12 @@ void TopLevel::openNetFile( const QString& _url)
   }
 
   setGeneralStatusField(i18n("Downloading..."));
-  tmpFile = QString::null; // let NetAccess decide about it
-  if ( KIO::NetAccess::download( netFile, tmpFile ) )
+  QString tmpFile = QString::null; // let NetAccess decide about it
+  if ( KIO::NetAccess::download( u, tmpFile ) )
   {
-    setGeneralStatusField( i18n("Finished '%1'").arg(tmpFile) );
+    setGeneralStatusField( i18n("Finished '%1'").arg(u.prettyURL()) );
     openadd( tmpFile );
-    setCaption( netFile );
+    setCaption( u.prettyURL() );
 	
     // Clean up
     KIO::NetAccess::removeTempFile( tmpFile );
@@ -1180,12 +1042,12 @@ void TopLevel::readSettings()
 	editor_height = config->readNumEntry("Height", 400);
 
         // Inverse logic. Default is "show statusbar".
-        hide_statusbar = config->readBoolEntry( "StatusBar", true ); 
+        hide_statusbar = config->readBoolEntry( "StatusBar", true );
         toggleStatusBar();
 
         // Inverse logic. Default is "show toolbar".
         hide_toolbar = config->readBoolEntry("ToolBar", true);
-        toggleToolBar(); 
+        toggleToolBar();
 
 	QString str = config->readEntry( "Toolbar position" );
 	if ( !str.isNull() ) {
@@ -1830,7 +1692,7 @@ void TopLevel::helptiff(){
     return;
 
   if (helppage == NULL) {
-    if (!notetiff( locate("toolbar", "kfax.tif").ascii() )) {
+    if (!notetiff( QFile::encodeName(locate("toolbar", "kfax.tif")) )) {
       return;
     }
     else {
@@ -1869,7 +1731,7 @@ void TopLevel::goToEnd(){
     putImage();
   }
   else
-    error();
+    KNotifyClient::beep(i18n("There is no further page."));
 
 }
 void TopLevel::goToStart(){
@@ -1893,7 +1755,7 @@ void TopLevel::goToStart(){
     putImage();
   }
   else
-    error();
+    KNotifyClient::beep(i18n("You are already on the first page."));
 
 }
 void TopLevel::nextPage(){
@@ -1903,7 +1765,7 @@ void TopLevel::nextPage(){
 
   if (thispage->next == NULL) {
 
-    error();
+    KNotifyClient::beep(i18n("There is no further page."));
     return;
   }
 
@@ -1921,7 +1783,7 @@ void TopLevel::prevPage(){
 
   if (thispage->prev == NULL){
 
-    error();
+    KNotifyClient::beep(i18n("There is no previous page."));
     return;
 
   }
@@ -2069,12 +1931,6 @@ void TopLevel::FreeFax(){
 }
 
 
-void TopLevel::error(){
-
-  QApplication::beep();
-
-}
-
 void TopLevel::uiUpdate(){
 
 
@@ -2250,7 +2106,6 @@ void TopLevel::putImage(){
     XFlush(qtdisplay);
   }
 
-
   ox = xpos;
   oy = ypos;
 
