@@ -279,7 +279,7 @@ int viewfaxmain()
     firstpage = lastpage = thispage = helppage = auxpage =  0;
 
     for (int i = 0; i < args->count(); i++){
-	(void) notetiff(QFile::decodeName(args->arg(i)));
+	(void) notetiff(args->arg(i));
     }
     args->clear();
 
