@@ -110,7 +110,7 @@ void InterpreterDialog::slotPaletteChange(bool)
 
 void InterpreterDialog::setup()
 {
-  mInterpreterEdit->setText( i18n("gs") );
+  mInterpreterEdit->setText( mInterpreterPath );
   mAntiAliasCheck->setChecked( mAntialias ); 
   mPlatformFontCheck->setChecked( mPlatformFonts ); 
   mMessagesCheck->setChecked( mShowMessages ); 
@@ -124,31 +124,37 @@ void InterpreterDialog::setup()
 }
 
 
-bool InterpreterDialog::antiAlias()
+QString InterpreterDialog::interpreterPath() const
+{
+  return mInterpreterPath;
+}
+
+
+bool InterpreterDialog::antiAlias() const
 {
   return mAntialias;
 }
 
 
-bool InterpreterDialog::showMessages()
+bool InterpreterDialog::showMessages() const
 {
   return mShowMessages;
 }
 
 
-bool InterpreterDialog::platformFonts()
+bool InterpreterDialog::platformFonts() const
 {
   return mPlatformFonts;
 }
 
 
-int InterpreterDialog::paletteType()
+int InterpreterDialog::paletteType() const
 {
   return mPaletteType;
 }
 
 
-int InterpreterDialog::backingStoreType()
+int InterpreterDialog::backingStoreType() const
 {
   return mBackingType;
 }
@@ -156,9 +162,10 @@ int InterpreterDialog::backingStoreType()
 
 void InterpreterDialog::slotOk()
 {
-  mAntialias     = mAntiAliasCheck->isChecked();
-  mShowMessages  = mMessagesCheck->isChecked();
-  mPlatformFonts = mPlatformFontCheck->isChecked();
+  mInterpreterPath  = mInterpreterEdit->text();
+  mAntialias	    = mAntiAliasCheck->isChecked();
+  mShowMessages	    = mMessagesCheck->isChecked();
+  mPlatformFonts    = mPlatformFontCheck->isChecked();
   if( mColorRadio->isChecked() )
     mPaletteType = COLOR_PALETTE;
   else if( mGrayscaleRadio->isChecked() )
@@ -178,11 +185,12 @@ void InterpreterDialog::slotOk()
 
 void InterpreterDialog::slotDefault()
 {
-  mAntialias     = true;
-  mShowMessages  = true;
-  mPlatformFonts = false;
-  mPaletteType   = COLOR_PALETTE;
-  mBackingType   = PIX_BACKING;
+  mInterpreterPath  = "gs";
+  mAntialias	    = true;
+  mShowMessages	    = true;
+  mPlatformFonts    = false;
+  mPaletteType	    = COLOR_PALETTE;
+  mBackingType	    = PIX_BACKING;
   setup();
 }
 
@@ -193,6 +201,7 @@ void InterpreterDialog::readSettings()
   KConfig &config = *KGVFactory::instance()->config();
   config.setGroup( "General" );
   
+  mInterpreterPath = config.readEntry( "Interpreter", "gs" );
   mAntialias = config.readBoolEntry( "Antialiasing", true );
   mShowMessages = config.readBoolEntry( "Messages", false );
   mPlatformFonts = config.readBoolEntry( "Platform fonts", false );
@@ -219,6 +228,7 @@ void InterpreterDialog::writeSettings()
   //Don't set the group in here.
   KConfig &config = *KGVFactory::instance()->config();
 
+  config.writeEntry( "Interpreter", mInterpreterPath );
   config.writeEntry( "Antialiasing", mAntialias );
   config.writeEntry( "Platform fonts", mPlatformFonts );
   config.writeEntry( "Messages", mShowMessages );
