@@ -21,12 +21,13 @@
 #ifndef _INTERPRETER_DIALOG_H_
 #define _INTERPRETER_DIALOG_H_
 
+#include <qstring.h>
+#include <kdialogbase.h>
+
 class QCheckBox;
 class QLineEdit;
 class QRadioButton;
 
-#include <kdialogbase.h>
-
 class InterpreterDialog : public KDialogBase 
 {
   Q_OBJECT
@@ -41,20 +42,21 @@ class InterpreterDialog : public KDialogBase
     void readSettings();
     void writeSettings();
 
-    bool antiAlias();
-    bool showMessages();
-    bool platformFonts();
-    int  paletteType();
-    int  backingStoreType();
+    QString interpreterPath()	const;
+    bool    antiAlias()		const;
+    bool    showMessages()	const;
+    bool    platformFonts()	const;
+    int	    paletteType()	const;
+    int	    backingStoreType()	const;
 
   protected slots:
     virtual void slotOk();
     virtual void slotDefault();
-    void slotAaToggled(bool);
-    void slotPaletteChange(bool);
+    void slotAaToggled( bool );
+    void slotPaletteChange( bool );
 
   private:
-    QLineEdit *mInterpreterEdit;
+    QLineEdit *mInterpreterEdit; // TODO: use a url requester instead.
     QCheckBox *mAntiAliasCheck;
     QCheckBox *mPlatformFontCheck;
     QCheckBox *mMessagesCheck;
@@ -64,11 +66,12 @@ class InterpreterDialog : public KDialogBase
     QRadioButton *mPixmapRadio;
     QRadioButton *mBackingStoreRadio;
 
-    bool mAntialias;
-    bool mShowMessages;
-    bool mPlatformFonts;
-    int  mPaletteType;
-    int  mBackingType;
+    QString mInterpreterPath;
+    bool    mAntialias;
+    bool    mShowMessages;
+    bool    mPlatformFonts;
+    int	    mPaletteType;
+    int	    mBackingType;
 };
 
 #endif 
