@@ -40,9 +40,10 @@ class MarkListTable: public QTableView
 	Q_OBJECT
 
 public:
+	friend class MarkList;
 	MarkListTable( QWidget * parent = 0, const char * name = 0 );
 	~MarkListTable();
-	QStringList	markList();
+	QValueList<int> markList();
 	void	insertItem ( const QString & text, int index=-1,
 			     const QString &tip = QString::null);
 	void	setAutoUpdate ( bool enable );
@@ -93,7 +94,7 @@ class MarkList: public QWidget
 public:
 	MarkList( QWidget * parent = 0, const char * name = 0 );
 	~MarkList() { }
-	QStringList	markList();
+	QValueList<int> markList();
 	void	insertItem ( const QString &text, int index=-1,
 			     const QString &tip = QString::null);
 	void	setAutoUpdate ( bool enable );
@@ -115,6 +116,7 @@ signals:
 	
 protected:
 	void resizeEvent( QResizeEvent * );
+	void wheelEvent( QWheelEvent* );
 
 private slots:
 	void	selectSig(int index);
