@@ -26,6 +26,8 @@
 #include <kcolordlg.h>
 #include <kfiledialog.h>
 #include <kmessagebox.h>
+#include <kdebug.h>
+#include <qcheckbox.h>
 
 #include "kiconconfig.h"
 
@@ -44,12 +46,12 @@ KTemplateEditDlg::KTemplateEditDlg(QWidget *parent) : QDialog(parent, 0, true)
   QVBoxLayout *l = new QVBoxLayout(grp, 25);
 
   ln_name = new QLineEdit( this );
-  connect( ln_name, SIGNAL( textChanged( const char* ) ), SLOT( slotTextChanged( const char* ) ) );
+  connect( ln_name, SIGNAL( textChanged( const QString & ) ), SLOT( slotTextChanged( const QString & ) ) );
 
   QLabel* lb_name = new QLabel( ln_name, i18n( "Description:" ), this );
 
   ln_path = new QLineEdit(this);
-  connect( ln_path, SIGNAL( textChanged( const char* ) ), SLOT( slotTextChanged( const char* ) ) );
+  connect( ln_path, SIGNAL( textChanged( const QString & ) ), SLOT( slotTextChanged( const QString & ) ) );
 
   QLabel* lb_path = new QLabel( ln_path, i18n( "Path:" ), this );
 
@@ -59,26 +61,26 @@ KTemplateEditDlg::KTemplateEditDlg(QWidget *parent) : QDialog(parent, 0, true)
   l->addWidget(ln_path);
 
   KButtonBox *bbox = new KButtonBox( this );
-	
+
   ok = bbox->addButton( i18n( "&OK" ) );
   connect( ok, SIGNAL( clicked() ), SLOT( accept() ) );
   ok->setEnabled(false);
-	
+
   cancel = bbox->addButton( i18n( "&Cancel" ) );
   connect( cancel, SIGNAL( clicked() ), SLOT( reject() ) );
-	
+
   bbox->addStretch( 1 );
-		
+
   browse = bbox->addButton( i18n( "&Browse..." ) );
   connect( browse, SIGNAL( clicked() ), SLOT( slotBrowse() ) );
-		
+
   bbox->layout();
 
   ml->addWidget( grp, 1);
   ml->addWidget( bbox );
 }
 
-void KTemplateEditDlg::slotTextChanged(const char *)
+void KTemplateEditDlg::slotTextChanged(const QString &)
 {
   QString name = ln_name->text(), path = ln_path->text();
   if(name.length() && path.length())
@@ -91,22 +93,22 @@ void KTemplateEditDlg::slotTextChanged(const char *)
   }
 }
 
-void KTemplateEditDlg::setName(QString name)
+void KTemplateEditDlg::setName(const QString & name)
 {
-  ln_name->setText(name.data());
+  ln_name->setText(name);
 }
 
-const char *KTemplateEditDlg::getName()
+QString KTemplateEditDlg::getName()
 {
   return ln_name->text();
 }
 
-void KTemplateEditDlg::setPath(QString path)
+void KTemplateEditDlg::setPath(const QString & path)
 {
-  ln_path->setText(path.data());
+  ln_path->setText(path);
 }
 
-const char *KTemplateEditDlg::getPath()
+QString KTemplateEditDlg::getPath()
 {
   return ln_path->text();
 }
@@ -129,14 +131,14 @@ void KTemplateEditDlg::slotBrowse()
 
 KTemplateConfig::KTemplateConfig(QWidget *parent) : QWidget(parent)
 {
-  debug("KTemplateConfig constructor");
+  kdDebug() << "KTemplateConfig constructor" << endl;
 
   btadd = btremove = btedit = 0L;
 
   QGroupBox* grp = new QGroupBox( i18n( "Templates:" ), this );
   templates = new KIconListBox( grp );
   connect( templates, SIGNAL( highlighted( int ) ), SLOT( checkSelection( int ) ) );
-
+  connect( templates, SIGNAL(doubleClicked( QListBoxItem * ) ), SLOT( edit() ) );
   QVBoxLayout* ml = new QVBoxLayout( this, 5 );
   ml->addWidget( grp );
 
@@ -150,14 +152,14 @@ KTemplateConfig::KTemplateConfig(QWidget *parent) : QWidget(parent)
     templates->insertItem( new KIconListBoxItem( tlist->at( i ) ) );
 
   KButtonBox *bbox = new KButtonBox( grp );
-	
+
   btadd = bbox->addButton( i18n( "&Add" ) );
   connect( btadd, SIGNAL( clicked() ), SLOT( add() ) );
-	
+
   btedit = bbox->addButton( i18n( "&Edit" ) );
   connect( btedit, SIGNAL( clicked() ), SLOT( edit() ) );
   btedit->setEnabled( false );
-	
+
   btremove = bbox->addButton( i18n( "&Remove" ) );
   connect( btremove, SIGNAL( clicked() ), SLOT( remove() ) );
   btremove->setEnabled( false );
@@ -170,7 +172,7 @@ KTemplateConfig::KTemplateConfig(QWidget *parent) : QWidget(parent)
 
 void KTemplateConfig::saveSettings()
 {
-  debug("KTemplateConfig::saveSettings");
+  kdDebug() << "KTemplateConfig::saveSettings" << endl;
 
   for(int i = 0; i < (int)templates->count(); i++)
   {
@@ -180,17 +182,17 @@ void KTemplateConfig::saveSettings()
       it->path = templates->path(i);
       it->title = templates->text(i);
       tlist->append(it);
-      debug("Name: %s\nPath: %s", templates->text(i).data(), templates->path(i).data());
-      debug("Name: %s\nPath: %s", it->path.data(), it->path.data());
+      kdDebug() << "Name: " << templates->text(i) << "\nPath: " << templates->path(i) << endl;
+      kdDebug() << "Name: " << it->path << "\nPath: " << it->path << endl;
     }
   }
-  debug("KTemplateConfig::saveSettings - done");
+  kdDebug() << "KTemplateConfig::saveSettings - done" << endl;
 
 }
 
 void KTemplateConfig::checkSelection(int)
 {
-  debug("KTemplateConfig::checkSelection");
+  kdDebug() << "KTemplateConfig::checkSelection" << endl;
   if(templates->currentItem() != -1)
   {
     if(btremove) btremove->setEnabled(true);
@@ -201,7 +203,7 @@ void KTemplateConfig::checkSelection(int)
     if(btremove) btremove->setEnabled(false);
     if(btedit) btedit->setEnabled(false);
   }
-  debug("KTemplateConfig::checkSelection - done");
+  kdDebug() << "KTemplateConfig::checkSelection - done" << endl;
 }
 
 void KTemplateConfig::remove()
@@ -225,22 +227,28 @@ void KTemplateConfig::add()
 void KTemplateConfig::edit()
 {
   KTemplateEditDlg dlg(this);
-  dlg.setPath(templates->path(templates->currentItem()).data());
+  dlg.setPath(templates->path(templates->currentItem()));
   dlg.setName(templates->text(templates->currentItem()));
+  templates->item(templates->currentItem());
   if(dlg.exec())
   {
-    KIconTemplate *it = new KIconTemplate;
+    KIconTemplate *it=templates->iconTemplate(templates->currentItem());
+    int pos=templates->currentItem();
     it->path = dlg.getPath();
     it->title = dlg.getName();
-    tlist->append(it);
-    templates->insertItem(new KIconListBoxItem(it));
+
+    //refresh list
+    templates->clear();
+    for( int i = 0; i < (int) tlist->count(); i++ )
+        templates->insertItem( new KIconListBoxItem( tlist->at( i ) ) );
+    templates->setCurrentItem(pos);
   }
 }
 
 KBackgroundConfig::KBackgroundConfig( QWidget* parent )
   : QWidget( parent )
 {
-  debug("KBackgroundConfig - constructor");
+  kdDebug() << "KBackgroundConfig - constructor" << endl;
 
   lb_ex = 0L;
 
@@ -248,10 +256,10 @@ KBackgroundConfig::KBackgroundConfig( QWidget* parent )
   color = pprops->backgroundcolor;
 
   pixpath = pprops->backgroundpixmap;
-  pix.load(pixpath.data());
+  pix.load(pixpath);
   if(pix.isNull())
   {
-    debug("BGPIX: %s not valid!", pixpath.data());
+    kdDebug() << "BGPIX: " << pixpath << " not valid!" << endl;
     QPixmap pmlogo((const char**)logo);
     pix = pmlogo;
   }
@@ -354,12 +362,12 @@ void KBackgroundConfig::slotBackgroundMode(int id)
 
 void KBackgroundConfig::saveSettings()
 {
-  debug("KBackgroundConfig::saveSettings");
+  kdDebug() << "KBackgroundConfig::saveSettings" << endl;
   Properties *pprops = props(this);
   pprops->backgroundmode = bgmode;
   pprops->backgroundpixmap = pixpath;
   pprops->backgroundcolor = color;
-  debug("KBackgroundConfig::saveSettings - done");
+  kdDebug() << "KBackgroundConfig::saveSettings - done" << endl;
 }
 
 void KBackgroundConfig::selectColor()
@@ -385,18 +393,18 @@ void KBackgroundConfig::selectPixmap()
     return;
   }
 
-  QPixmap p(url.path().data());
+  QPixmap p(url.path());
 
   if( !p.isNull() )
   {
     lb_ex->setBackgroundPixmap( p );
-    pixpath = url.path().data();
+    pixpath = url.path();
   }
 }
 
 KToolBarConfig::KToolBarConfig(QWidget *parent) : QWidget(parent)
 {
-  debug("KToolBarConfig - constructor");
+  kdDebug() << "KToolBarConfig - constructor" << endl;
 
   pprops = props(parent);
 
@@ -455,7 +463,7 @@ KToolBarConfig::KToolBarConfig(QWidget *parent) : QWidget(parent)
   connect(btngrptool, SIGNAL(clicked(int)), SLOT(mainToolBar(int)));
   connect(btngrpdraw, SIGNAL(clicked(int)), SLOT(drawToolBar(int)));
 
-  debug("KToolBarConfig - constructor done");
+  kdDebug() << "KToolBarConfig - constructor done" << endl;
 }
 
 KToolBarConfig::~KToolBarConfig()
@@ -465,7 +473,7 @@ KToolBarConfig::~KToolBarConfig()
 
 void KToolBarConfig::saveSettings()
 {
-  debug("KToolBarConfig::saveSettings");
+  kdDebug() << "KToolBarConfig::saveSettings" << endl;
 
   pprops->maintoolbartext = mstat;
   pprops->drawtoolbartext = dstat;
@@ -473,7 +481,7 @@ void KToolBarConfig::saveSettings()
   pprops->maintoolbar->setIconText((KToolBar::IconText)mstat);
   pprops->drawtoolbar->setIconText((KToolBar::IconText)dstat);
 
-  debug("KToolBarConfig::saveSettings - done");
+  kdDebug() << "KToolBarConfig::saveSettings - done" << endl;
 }
 
 void KToolBarConfig::drawToolBar(int i)
@@ -488,7 +496,7 @@ void KToolBarConfig::mainToolBar(int i)
 
 KMiscConfig::KMiscConfig(QWidget *parent) : QWidget(parent)
 {
-  debug("KMiscConfig - constructor");
+  kdDebug() << "KMiscConfig - constructor" << endl;
 
   pprops = props(parent);
 
@@ -499,23 +507,23 @@ KMiscConfig::KMiscConfig(QWidget *parent) : QWidget(parent)
 
   QBoxLayout *l1 = new  QVBoxLayout(grp1, 20);
 
-  QRadioButton *rbp = new QRadioButton( i18n( "Paste transparent pixels" ), grp1 );
-  connect( rbp, SIGNAL( toggled( bool ) ), SLOT( pasteMode( bool ) ) );
-  l1->addWidget(rbp);
+  QCheckBox *cbp = new QCheckBox( i18n( "Paste transparent pixels" ), grp1 );
+  connect( cbp, SIGNAL( toggled( bool ) ), SLOT( pasteMode( bool ) ) );
+  l1->addWidget(cbp);
 
-  QRadioButton *rbr = new QRadioButton( i18n( "Show rulers" ), grp1 );
-  connect( rbr, SIGNAL( toggled( bool ) ), SLOT( showRulers( bool ) ) );
-  l1->addWidget(rbr);
+  QCheckBox *cbr = new QCheckBox( i18n( "Show rulers" ), grp1 );
+  connect( cbr, SIGNAL( toggled( bool ) ), SLOT( showRulers( bool ) ) );
+  l1->addWidget(cbr);
 
   l1->addStretch(1);
 
   pastemode = pprops->pastetransparent;
   if(pastemode)
-    rbp->setChecked(true);
+    cbp->setChecked(true);
 
   showrulers = pprops->showrulers;
   if(showrulers)
-    rbr->setChecked(true);
+    cbr->setChecked(true);
 }
 
 KMiscConfig::~KMiscConfig()
@@ -525,7 +533,7 @@ KMiscConfig::~KMiscConfig()
 
 void KMiscConfig::saveSettings()
 {
-  debug("KMiscConfig::saveSettings");
+  kdDebug() << "KMiscConfig::saveSettings" << endl;
 
   pprops->pastetransparent = pastemode;
   pprops->showrulers = showrulers;
@@ -551,11 +559,11 @@ KIconConfig::KIconConfig(QWidget *parent)
   pprops = KIconEditProperties::getProperties(parent);
   //keys = k; //new KAccel(parent);
   //dict = new QDict<KKeyEntry>( k->keyDict() );
-  //debug("Keys: %u", k->keyDict().count());
-  //debug("Keys: %u", dict->count());
+  //kdDebug() << "Keys: " << k->keyDict().count() << endl;
+  //kdDebug() << "Keys: " << dict->count() << endl;
   //CHECK_PTR(dict);
   pprops->keydict = pprops->keys->keyDict();
-  debug("Keys: %u", pprops->keydict.count());
+  kdDebug() << "Keys: " << pprops->keydict.count() << endl;
 
   keychooser = new KKeyChooser( &pprops->keydict, this );
   addTab( keychooser, i18n( "Keys" ) );
@@ -580,7 +588,7 @@ KIconConfig::~KIconConfig()
 
 void KIconConfig::saveSettings()
 {
-  debug("KIconEditConfig::saveSettings");
+  kdDebug() << "KIconEditConfig::saveSettings" << endl;
 
   pprops->keys->setKeyDict( pprops->keydict );
   temps->saveSettings();
@@ -589,3 +597,4 @@ void KIconConfig::saveSettings()
   toolbars->saveSettings();
   accept();
 }
+#include "kiconconfig.moc"
