@@ -26,27 +26,27 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <ktoolbarbutton.h>
+#include <kdebug.h>
 
 #include "kiconedit.h"
-#include "kdragsource.h"
 #include "main.h"
 
 KIconEdit::KIconEdit(const QImage image, const char *name)
- : KTMainWindow(name)
+ : KMainWindow(0, name)
 {
-  init();
-  img = image;
-  img.detach();
-  grid->load(&img);
-  preview->setPixmap(grid->pixmap());
+    init();
+    img = image;
+    img.detach();
+    grid->load(&img);
+    preview->setPixmap(grid->pixmap());
 }
 
 KIconEdit::KIconEdit(const QString &xpm, const char *name)
- : KTMainWindow(name)
+ : KMainWindow(0, name)
 {
-  init();
-  icon->open(&img, xpm);
-  preview->setPixmap(grid->pixmap());
+    init();
+    icon->open(&img, xpm);
+    preview->setPixmap(grid->pixmap());
 }
 
 void KIconEdit::init()
@@ -74,7 +74,7 @@ void KIconEdit::init()
   icontemplates = new KIconTemplateContainer;
   CHECK_PTR(icontemplates);
 
-  gridview = new KGridView(&img, this); //viewport->viewport()); //KIconEditView(this);
+  gridview = new KGridView(&img, this); 
   CHECK_PTR(gridview);
   gridview->setShowRulers(pprops->showrulers);
 
@@ -88,17 +88,6 @@ void KIconEdit::init()
 
   setAcceptDrops(true);
 
-  dropsite = new KDropSite( grid );
-  CHECK_PTR(dropsite);
-  connect( dropsite, SIGNAL( dropAction( QDropEvent*) ), 
-    this, SLOT( slotQDropEvent( QDropEvent*) ) );
-
-  connect( dropsite, SIGNAL( dragLeave( QDragLeaveEvent*) ), 
-    this, SLOT( slotQDragLeaveEvent( QDragLeaveEvent*) ) );
-
-  connect( dropsite, SIGNAL( dragEnter( QDragEnterEvent*) ), 
-    this, SLOT( slotQDragEnterEvent( QDragEnterEvent*) ) );
-
   setupStatusBar();
   setupMenuBar();
   setupToolBar();
@@ -110,12 +99,12 @@ void KIconEdit::init()
            SLOT(slotSaved()));
   connect( icon, SIGNAL( loaded(QImage *)),
      grid, SLOT(load(QImage *)));
-  connect( icon, SIGNAL(opennewwin(const char *)),
-           SLOT(slotNewWin(const char *)));
-  connect(icon, SIGNAL(newname(const char *)),
-           SLOT( slotUpdateStatusName(const char *)));
-  connect(icon, SIGNAL(newmessage(const char *)),
-           SLOT( slotUpdateStatusMessage(const char *)));
+  connect( icon, SIGNAL(opennewwin(const QString &)),
+           SLOT(slotNewWin(const QString &)));
+  connect(icon, SIGNAL(newname(const QString &)),
+           SLOT( slotUpdateStatusName(const QString &)));
+  connect(icon, SIGNAL(newmessage(const QString &)),
+           SLOT( slotUpdateStatusMessage(const QString &)));
 
   connect( syscolors, SIGNAL( newcolor(uint)),
      grid, SLOT(setColorSelection(uint)));
@@ -139,69 +128,68 @@ void KIconEdit::init()
            SLOT(slotUpdateStatusColors(uint)));
   connect(grid, SIGNAL(colorschanged(uint, uint*)),
            SLOT( slotUpdateStatusColors(uint, uint*)));
-  connect(grid, SIGNAL(newmessage(const char *)),
-           SLOT( slotUpdateStatusMessage(const char *)));
+  connect(grid, SIGNAL(newmessage(const QString &)),
+           SLOT( slotUpdateStatusMessage(const QString &)));
   connect(grid, SIGNAL(clipboarddata(bool)),
            SLOT( slotUpdatePaste(bool)));
   connect(grid, SIGNAL(selecteddata(bool)),
            SLOT( slotUpdateCopy(bool)));
 
-  debug("Setting tool");
+  kdDebug() << "Setting tool" << endl;
   slotTools(ID_DRAW_FIND);
-  debug("Updating statusbar");
+  
+  kdDebug() << "Updating statusbar" << endl;
   slotUpdateStatusSize(grid->cols(), grid->rows());
+  
   slotUpdateStatusScaling(grid->scaling(), true);
+  
   if(icon->url().length())
-    slotUpdateStatusName(icon->url().data());
+    slotUpdateStatusName(icon->url());
+  
   slotUpdateCopy(false);
+  
   uint *c = 0, n = 0;
   n = grid->getColors(c);
   slotUpdateStatusColors(n, c);
-  setView(gridview);
+  
+  setCentralWidget(gridview);
 
   if((pprops->winwidth > 0) && (pprops->winheight > 0))
     resize( pprops->winwidth, pprops->winheight );
 
-  debug("Showing");
+  kdDebug() << "Showing" << endl;
   show();
 }
 
 KIconEdit::~KIconEdit()
 {
-/*  the following should be destructed by the QObject/QWidget destructor
-    if(l)
-      delete l;
-    l = 0L; 
-    if(grid)
-      delete grid;
-    grid = 0L; 
-    if(toolsw)
-      delete toolsw;
-    toolsw = 0L; 
-    if(newicon)
-      delete newicon;
-    newicon = 0L; 
-*/
     if(printer)
       delete printer;
+
     if(what)
       delete what;
     what = 0L;
+
     if(toolbar)
       delete toolbar;
     toolbar = 0L; 
+
     if(drawtoolbar)
       delete drawtoolbar;
     drawtoolbar = 0L; 
+
     if(menubar)
       delete menubar;
     menubar = 0L; 
+
     if(statusbar)
       delete statusbar;
     statusbar = 0L; 
+
     if(icontemplates)
       delete icontemplates;
     icontemplates = 0L;
+
     delete file;
     delete edit;
     delete view;
@@ -215,114 +203,91 @@ KIconEdit::~KIconEdit()
 
 bool KIconEdit::queryClose()
 {
-  bool cancel = false;
-  if (grid->isModified()) 
-  {
-    //KWM::activate(winId());
-    int r = KMessageBox::warningYesNoCancel(this,
-		i18n("The current file has been modified.\nDo you want to save it?"));
-    switch(r)
+    bool cancel = false;
+    if (grid->isModified()) 
     {
-      case 0:
-        icon->save(&grid->image());
-        //grid->save(grid->drawPath());
-        break;
-      case 1:
-        break;
-      case 2:
-        cancel = true;
-        break;
-      default:
-        break;
+        int r = KMessageBox::warningYesNoCancel(this,
+	    i18n("The current file has been modified.\nDo you want to save it?"));
+
+        switch(r)
+        {
+            case 0:
+                icon->save(&grid->image());
+                break;
+            case 1:
+                break;
+            case 2:
+                cancel = true;
+                break;
+            default:
+                break;
+        }
     }
-  }
-  if(!cancel)
-  {
-    writeConfig();
-    icon->cleanup();
-  }
-  return (!cancel);
+    
+    if(!cancel)
+    {
+        writeConfig();
+    }
+    return (!cancel);
 }
 
+/* 
+    save size of the application window
+*/
 void KIconEdit::resizeEvent( QResizeEvent * )
 {
-  // save size of the application window
-  //debug("KIconEdit::resizeEvent()");
+
+  //kdDebug() << "KIconEdit::resizeEvent()" << endl;
+  
   props(this)->winwidth = geometry().width();
   props(this)->winheight = geometry().height();
-
-  updateRects();
+  
   //viewport->updateScrollBars();
 }
 
 void KIconEdit::unsaved( bool /*flag*/ )
 {
-#warning fix session management
     //setUnsavedData(flag);
 }
 
-void KIconEdit::saveGoingDownStatus()
-{
-  debug("KIconEdit::saveGoingDownStatus");
-  if( grid->isModified() )
-  {
-    debug("Saving backup for modified file %s", icon->url().data());
-    icon->saveBackup(&grid->image());
-  }
-  else
-    icon->cleanup();
-  debug("KIconEdit::saveGoingDownStatus - done");
-}
-
 // this is for exit by request of the session manager
 void KIconEdit::saveProperties(KConfig *config )
 {
-  debug("KIconEdit::saveProperties");
-  config->writeEntry("Name", icon->url());
-  saveGoingDownStatus();
+    kdDebug() << "KIconEdit::saveProperties" << endl;
+    
+    config->writeEntry("Name", icon->url());
 }
 
 // this is for instances opened by the session manager
 void KIconEdit::readProperties(KConfig *config)
 {
-  debug("KIconEdit::readProperties");
-  QString entry = config->readEntry("Name", ""); // no default
-  if (entry.isEmpty())
-    return;
-  icon->open(&grid->image(), entry.data());
+    kdDebug() << "KIconEdit::readProperties" << endl;
+    
+    QString entry = config->readEntry("Name", ""); // no default
+    if (entry.isEmpty())  return;
+    icon->open(&grid->image(), entry);
 }
 
-// this is for normal exits or request from "Options->Save options".
+/* 
+    this is for normal exits or request from "Options->Save options".
+*/
+    
 void KIconEdit::writeConfig()
 {
-/*
-  Properties *pprops = props(this);
-  
-  pprops->maintoolbarstat = toolbar->isVisible();
-  pprops->drawtoolbarstat = drawtoolbar->isVisible();
-  pprops->statusbarstat = statusbar->isVisible();
-
-  pprops->maintoolbarpos = toolbar->barPos();
-  pprops->drawtoolbarpos = drawtoolbar->barPos();
-
-  //pprops->showgrid = grid->hasGrid();
-  //pprops->gridscaling = grid->cellSize();
-*/
-  KIconEditProperties::saveProperties(this);
-
+    KIconEditProperties::saveProperties(this);
 }
 
 QSize KIconEdit::sizeHint() const
 {
-  if(gridview)
-    return gridview->sizeHint();
-  else
-    return QSize(-1, -1);
+    if(gridview)
+        return gridview->sizeHint();
+    else
+        return QSize(-1, -1);
 }
 
 bool KIconEdit::setupMenuBar()
 {
-  debug("setupMenuBar");
+  kdDebug() << "setupMenuBar" << endl;
 
   Properties *pprops = props(this);
 
@@ -330,11 +295,10 @@ bool KIconEdit::setupMenuBar()
   {
     menubar = new KMenuBar(this);
     CHECK_PTR(menubar);
-    setMenu(menubar);
     pprops->menubar = menubar;
   }
 
-  KAccel *keys = pprops->keys; // = new KAccel( this ); 
+  KAccel *keys = pprops->keys; 
   CHECK_PTR(keys);
 
   keys->connectItem( KStdAccel::New, this, SLOT(slotNew()) );
@@ -350,37 +314,37 @@ bool KIconEdit::setupMenuBar()
   keys->connectItem( "Select All", this, SLOT(slotSelectAll()) );
   keys->readSettings();
 
-  debug("setupMenuBar - read settings");
-
+  kdDebug() << "setupMenuBar - read settings" << endl;
 
   recent = new QPopupMenu;
   CHECK_PTR(recent);
   connect( recent, SIGNAL(activated(int)), SLOT(slotOpenRecent(int)));
-  for(uint i = 0; i < pprops->recentlist->count(); i++)
-    recent->insertItem(pprops->recentlist->at(i));
+
+  for ( QStringList::Iterator it = pprops->recentlist->begin();
+  it != pprops->recentlist->end(); ++it )
+        recent->insertItem(*it);
 
   int id;
 
   file = new QPopupMenu;
   CHECK_PTR(file);
 
-  file->insertItem(BarIcon("newwin"), i18n("New &Window"), ID_FILE_NEWWIN);
+  file->insertItem(SmallIcon("newwin"), i18n("New &Window"), ID_FILE_NEWWIN);
   file->connectItem(ID_FILE_NEWWIN, this, SLOT(slotNewWin()));
 
   file->insertSeparator();
 
-  id = file->insertItem(BarIcon("filenew"), i18n("&New..."), ID_FILE_NEWFILE);
+  id = file->insertItem(SmallIcon("filenew"), i18n("&New..."), ID_FILE_NEWFILE);
   file->connectItem(ID_FILE_NEWFILE, this, SLOT(slotNew()));
 
-  id = file->insertItem(BarIcon("fileopen"), i18n("&Open..."), ID_FILE_OPEN);
+  id = file->insertItem(SmallIcon("fileopen"), i18n("&Open..."), ID_FILE_OPEN);
   file->connectItem(ID_FILE_OPEN, this, SLOT(slotOpen()));
 
   file->insertItem(i18n("Open recent"), recent, ID_FILE_RECENT);
-  //file->setItemEnabled(ID_FILE_RECENT, false);
 
   file->insertSeparator();
 
-  id = file->insertItem(BarIcon("filefloppy"), i18n("&Save"), ID_FILE_SAVE);
+  id = file->insertItem(SmallIcon("filesave"), i18n("&Save"), ID_FILE_SAVE);
   file->connectItem(ID_FILE_SAVE, this, SLOT(slotSave()));
 
   file->insertItem(i18n("S&ave as..."), ID_FILE_SAVEAS);
@@ -388,29 +352,26 @@ bool KIconEdit::setupMenuBar()
 
   file->insertSeparator();
 
-  id = file->insertItem(BarIcon("fileprint"), i18n("&Print..."), ID_FILE_PRINT);
+  id = file->insertItem(SmallIcon("fileprint"), i18n("&Print..."), ID_FILE_PRINT);
   file->connectItem(ID_FILE_PRINT, this, SLOT(slotPrint()));
 
   file->insertSeparator();
 
-  id = file->insertItem(BarIcon("fileclose"), i18n("&Close"), ID_FILE_CLOSE);
+  id = file->insertItem(SmallIcon("fileclose"), i18n("&Quit"), ID_FILE_CLOSE);
   file->connectItem(ID_FILE_CLOSE, this, SLOT(slotClose()));
 
-  id = file->insertItem(i18n("&Exit"), ID_FILE_QUIT);
-  file->connectItem(ID_FILE_QUIT, this, SLOT(slotQuit()));
-
   menubar->insertItem(i18n("&File"), file);
 
   edit = new QPopupMenu;
   CHECK_PTR(edit);
 
-  id = edit->insertItem(BarIcon("editcut"), i18n("Cu&t"), ID_EDIT_CUT);
+  id = edit->insertItem(SmallIcon("editcut"), i18n("Cu&t"), ID_EDIT_CUT);
   edit->connectItem(ID_EDIT_CUT, this, SLOT(slotCut()));
 
-  id = edit->insertItem(BarIcon("editcopy"), i18n("&Copy"), ID_EDIT_COPY);
+  id = edit->insertItem(SmallIcon("editcopy"), i18n("&Copy"), ID_EDIT_COPY);
   edit->connectItem(ID_EDIT_COPY, this, SLOT(slotCopy()));
 
-  id = edit->insertItem(BarIcon("editpaste"), i18n("&Paste"), ID_EDIT_PASTE);
+  id = edit->insertItem(SmallIcon("editpaste"), i18n("&Paste"), ID_EDIT_PASTE);
   edit->connectItem(ID_EDIT_PASTE, this, SLOT(slotPaste()));
 
   id = edit->insertItem(i18n("Paste as &new"), ID_EDIT_PASTE_AS_NEW);
@@ -434,38 +395,38 @@ bool KIconEdit::setupMenuBar()
 
   view = new QPopupMenu;
   CHECK_PTR(view);
-  id = view->insertItem(BarIcon("viewmag+"), i18n("Zoom &in"), ID_VIEW_ZOOM_IN);
-  id = view->insertItem(BarIcon("viewmag-"), i18n("Zoom &out"), ID_VIEW_ZOOM_OUT);
-  id = view->insertItem(BarIcon("viewmag"), i18n("Zoom factor"), zoom);
+  id = view->insertItem(SmallIcon("viewmag+"), i18n("Zoom &in"), ID_VIEW_ZOOM_IN);
+  id = view->insertItem(SmallIcon("viewmag-"), i18n("Zoom &out"), ID_VIEW_ZOOM_OUT);
+  id = view->insertItem(SmallIcon("viewmag"), i18n("Zoom factor"), zoom);
   connect( view, SIGNAL(activated(int)), SLOT(slotView(int)));
   menubar->insertItem(i18n("&View"), view);
 
   image = new QPopupMenu;
   CHECK_PTR(image);
-#if QT_VERSION >= 140
-  id = image->insertItem(BarIcon("transform"), i18n("&Resize"), ID_IMAGE_RESIZE);
-#endif
-  id = image->insertItem(BarIcon("grayscale"), i18n("&GrayScale"), ID_IMAGE_GRAYSCALE);
+
+  id = image->insertItem(SmallIcon("transform"), i18n("&Resize"), ID_IMAGE_RESIZE);
+  id = image->insertItem(SmallIcon("grayscale"), i18n("&GrayScale"), ID_IMAGE_GRAYSCALE);
   
-  //id = image->insertItem(BarIcon("kdepalette"), i18n("&Map to KDE palette"), ID_IMAGE_MAPTOKDE);
+  //id = image->insertItem(SmallIcon("kdepalette"), i18n("&Map to KDE palette"), ID_IMAGE_MAPTOKDE);
   
   connect( image, SIGNAL(activated(int)), SLOT(slotImage(int)));
   menubar->insertItem(i18n("&Icon"), image);
 
   tools = new QPopupMenu;
   CHECK_PTR(tools);
-  tools->insertItem(BarIcon("paintbrush"), i18n("Freehand"), ID_DRAW_FREEHAND);
-  tools->insertItem(BarIcon("rectangle"), i18n("Rectangle"), ID_DRAW_RECT);
-  tools->insertItem(BarIcon("filledrectangle"), i18n("Filled rectangle"), ID_DRAW_RECT_FILL);
-  tools->insertItem(BarIcon("circle"), i18n("Circle"), ID_DRAW_CIRCLE);
-  tools->insertItem(BarIcon("filledcircle"), i18n("Filled circle"), ID_DRAW_CIRCLE_FILL);
-  tools->insertItem(BarIcon("ellipse"), i18n("Ellipse"), ID_DRAW_ELLIPSE);
-  tools->insertItem(BarIcon("filledellipse"), i18n("Filled ellipse"), ID_DRAW_ELLIPSE_FILL);
-  tools->insertItem(BarIcon("spraycan"), i18n("Spray"), ID_DRAW_SPRAY);
-  tools->insertItem(BarIcon("flood"), i18n("Flood fill"), ID_DRAW_FILL);
-  tools->insertItem(BarIcon("line"), i18n("Line"), ID_DRAW_LINE);
-  tools->insertItem(BarIcon("eraser"), i18n("Eraser (Transparent)"), ID_DRAW_ERASE);
-  //tools->insertSeparator();
+  tools->insertItem(SmallIcon("paintbrush"), i18n("Freehand"), ID_DRAW_FREEHAND);
+  tools->insertItem(SmallIcon("rectangle"), i18n("Rectangle"), ID_DRAW_RECT);
+  tools->insertItem(SmallIcon("filledrectangle"), i18n("Filled rectangle"), ID_DRAW_RECT_FILL);
+  tools->insertItem(SmallIcon("circle"), i18n("Circle"), ID_DRAW_CIRCLE);
+  tools->insertItem(SmallIcon("filledcircle"), i18n("Filled circle"), ID_DRAW_CIRCLE_FILL);
+  tools->insertItem(SmallIcon("ellipse"), i18n("Ellipse"), ID_DRAW_ELLIPSE);
+  tools->insertItem(SmallIcon("filledellipse"), i18n("Filled ellipse"), ID_DRAW_ELLIPSE_FILL);
+  tools->insertItem(SmallIcon("spraycan"), i18n("Spray"), ID_DRAW_SPRAY);
+  tools->insertItem(SmallIcon("flood"), i18n("Flood fill"), ID_DRAW_FILL);
+  tools->insertItem(SmallIcon("line"), i18n("Line"), ID_DRAW_LINE);
+  
+  tools->insertItem(SmallIcon("eraser"), i18n("Eraser (Transparent)"), ID_DRAW_ERASE);
+
   connect( tools, SIGNAL(activated(int)), SLOT(slotTools(int)));
   menubar->insertItem(i18n("&Tools"), tools);
 
@@ -473,47 +434,40 @@ bool KIconEdit::setupMenuBar()
   CHECK_PTR(options);
   id = options->insertItem(i18n("&Configure"), ID_OPTIONS_CONFIGURE);
   options->insertSeparator();
-  options->insertItem(i18n("Toggle &Grid"), ID_OPTIONS_TOGGLE_GRID);
+  options->insertItem(i18n("Show &Grid"), ID_OPTIONS_TOGGLE_GRID);
   if(pprops->showgrid)
     options->setItemChecked(ID_OPTIONS_TOGGLE_GRID, true);
-  options->insertItem(i18n("Toggle &toolbar"), ID_OPTIONS_TOGGLE_TOOL1);
+  options->insertItem(i18n("Show &toolbar"), ID_OPTIONS_TOGGLE_TOOL1);
   if(pprops->maintoolbarstat)
     options->setItemChecked(ID_OPTIONS_TOGGLE_TOOL1, true);
-  options->insertItem(i18n("Toggle &drawing tools"), ID_OPTIONS_TOGGLE_TOOL2);
+  options->insertItem(i18n("Show &drawing tools"), ID_OPTIONS_TOGGLE_TOOL2);
   if(pprops->drawtoolbarstat)
     options->setItemChecked(ID_OPTIONS_TOGGLE_TOOL2, true);
-  options->insertItem(i18n("Toggle &statusbar"), ID_OPTIONS_TOGGLE_STATS);
+  options->insertItem(i18n("Show &statusbar"), ID_OPTIONS_TOGGLE_STATS);
   if(pprops->statusbarstat)
     options->setItemChecked(ID_OPTIONS_TOGGLE_STATS, true);
   options->insertSeparator();
-  options->insertItem(BarIcon("filefloppy"), i18n("&Save options"), ID_OPTIONS_SAVE);
+  options->insertItem(SmallIcon("filesave"), i18n("&Save options"), ID_OPTIONS_SAVE);
   connect( options, SIGNAL(activated(int)), SLOT(slotConfigure(int)));
   menubar->insertItem(i18n("&Options"), options);
 
   menubar->insertSeparator();
 
-  QString about;
-  about.sprintf(i18n("KDE Icon Editor\n\n"
-                     "A graphics drawing program for creating\n"
-                     "icons using the KDE icon palette\n\n"
-                     "Copyright 1998 by Thomas Tanghus\n"
-                     "tanghus@kde.org\n"
-                     "http://w1.1358.telia.com/~u135800018"));
+  help = helpMenu();
 
-  help = helpMenu(about.data());
   menubar->insertItem(i18n("&Help"), help);
 
   updateMenuAccel();
   menubar->show();
   //connect( menubar, SIGNAL(activated(int)), SLOT(slotActions(int)));
 
-  debug("setupMenuBar - done");
+  kdDebug() << "setupMenuBar - done" << endl;
   return true;
 }
 
 void KIconEdit::updateMenuAccel()
 {
-  KAccel *keys = props(this)->keys; // = new KAccel( this ); 
+  KAccel *keys = props(this)->keys;  
   CHECK_PTR(keys);
 
   keys->changeMenuAccel(file, ID_FILE_NEWFILE, KStdAccel::New); 
@@ -533,28 +487,21 @@ void KIconEdit::updateMenuAccel()
 bool KIconEdit::setupToolBar()
 {
   Properties *pprops = props(this);
-  debug("setupToolBar");
+  kdDebug() << "setupToolBar" << endl;
 
-  toolbar = new KToolBar(this);
+  toolbar = toolBar();
   CHECK_PTR(toolbar);
-  addToolBar(toolbar);
   pprops->maintoolbar = toolbar;
 
   QWidget *btwhat = (QWidget*)what->whatsThisButton(toolbar);
   what = new QWhatsThis(btwhat);
   QToolTip::add(btwhat, i18n("What is ...?"));
 
-  dragbutton = new KDragSource("image/x-xpm", grid, SLOT(getImage(QImage*)), toolbar);
-  dragbutton->setPixmap(BarIcon("image"));
-  QToolTip::add(dragbutton, i18n("Drag source"));
-
-  toolbar->insertWidget(-1, 22, dragbutton);
-  toolbar->insertSeparator();
   toolbar->insertButton(BarIcon("filenew"), ID_FILE_NEWFILE,
          SIGNAL(clicked()), this, SLOT(slotNew()), TRUE, i18n("New File"));
   toolbar->insertButton(BarIcon("fileopen"),ID_FILE_OPEN,
          SIGNAL(clicked()), this, SLOT(slotOpen()), TRUE, i18n("Open a file"));
-  toolbar->insertButton(BarIcon("filefloppy"), ID_FILE_SAVE,
+  toolbar->insertButton(BarIcon("filesave"), ID_FILE_SAVE,
          SIGNAL(clicked()), this, SLOT(slotSave()), TRUE, i18n("Save the file"));
   toolbar->insertSeparator();
   toolbar->insertButton(BarIcon("fileprint"),ID_FILE_PRINT,
@@ -569,18 +516,18 @@ bool KIconEdit::setupToolBar()
 
   select = new QPopupMenu;
   CHECK_PTR(select);
-  select->insertItem(BarIcon("selectrect"), ID_SELECT_RECT);
-  select->insertItem(BarIcon("selectcircle"), ID_SELECT_CIRCLE);
+  select->insertItem(SmallIcon("selectrect"), ID_SELECT_RECT);
+  select->insertItem(SmallIcon("selectcircle"), ID_SELECT_CIRCLE);
   connect( select, SIGNAL(activated(int)), SLOT(slotTools(int)));
 
   toolbar->insertButton(BarIcon("areaselect"), ID_SELECT, select, true, i18n("Select area"));
   //drawtoolbar->setToggle(ID_DRAW_SELECT, true);
 
   toolbar->insertSeparator();
-#if QT_VERSION >= 140
+
   toolbar->insertButton(BarIcon("transform"),ID_IMAGE_RESIZE, TRUE, 
 			  i18n("Resize"));
-#endif
+
   toolbar->insertButton(BarIcon("grayscale"),ID_IMAGE_GRAYSCALE, TRUE, 
 			  i18n("GrayScale"));
 /*
@@ -603,7 +550,7 @@ bool KIconEdit::setupToolBar()
 
   toolbar->insertSeparator();
 
-  toolbar->insertWidget(ID_HELP_WHATSTHIS, btwhat->sizeHint().width(), btwhat);
+//  toolbar->insertWidget(ID_HELP_WHATSTHIS, btwhat->sizeHint().width(), btwhat);
 
   toolbar->insertButton(BarIcon("newwin"),ID_FILE_NEWWIN,
          SIGNAL(clicked()), this, SLOT(slotNewWin()), TRUE,
@@ -613,140 +560,140 @@ bool KIconEdit::setupToolBar()
   toolbar->setIconText((KToolBar::IconText) pprops->maintoolbartext);
   toolbar->setBarPos(pprops->maintoolbarpos);
   if(pprops->maintoolbarstat)
-    toolbar->enable(KToolBar::Show);
+    toolbar->show();
   else
-    toolbar->enable(KToolBar::Hide);
-  //toolbar->show();
+    toolbar->hide();
   connect( toolbar, SIGNAL(clicked(int)), SLOT(slotView(int)));
   connect( toolbar, SIGNAL(clicked(int)), SLOT(slotImage(int)));
   connect( toolbar, SIGNAL(clicked(int)), SLOT(slotConfigure(int)));
 
-  debug("setupToolBar - done");
+  kdDebug() << "setupToolBar - done" << endl;
   return true;
 }
 
 bool KIconEdit::setupDrawToolBar()
 {
-  debug("setupDrawToolBar");
+  kdDebug() << "setupDrawToolBar" << endl;
   Properties *pprops = props(this);
-  drawtoolbar = new KToolBar(this);
-  CHECK_PTR(drawtoolbar);
-  addToolBar(drawtoolbar);
+  drawtoolbar = new KToolBar(this, "drawToolBar");
   pprops->drawtoolbar = drawtoolbar;
   drawtoolbar->setFullSize();
 
   drawtoolbar->insertButton(BarIcon("pointer"), ID_DRAW_FIND, TRUE, i18n("Find pixel"));
   drawtoolbar->setToggle(ID_DRAW_FIND, true);
+
   drawtoolbar->insertButton(BarIcon("paintbrush"), ID_DRAW_FREEHAND, TRUE, i18n("Draw freehand"));
   drawtoolbar->setToggle(ID_DRAW_FREEHAND, true);
 
   drawtoolbar->insertButton(BarIcon("line"), ID_DRAW_LINE, TRUE, i18n("Draw line"));
   drawtoolbar->setToggle(ID_DRAW_LINE, true);
+
   drawtoolbar->insertButton(BarIcon("rectangle"),ID_DRAW_RECT, TRUE, i18n("Draw rectangle"));
   drawtoolbar->setToggle(ID_DRAW_RECT, true);
+
   drawtoolbar->insertButton(BarIcon("filledrectangle"),ID_DRAW_RECT_FILL, TRUE, i18n("Draw filled rectangle"));
   drawtoolbar->setToggle(ID_DRAW_RECT_FILL, true);
+
   drawtoolbar->insertButton(BarIcon("circle"),ID_DRAW_CIRCLE, TRUE, i18n("Draw circle"));
   drawtoolbar->setToggle(ID_DRAW_CIRCLE, true);
+
   drawtoolbar->insertButton(BarIcon("filledcircle"),ID_DRAW_CIRCLE_FILL, TRUE, i18n("Draw filled circle"));
   drawtoolbar->setToggle(ID_DRAW_CIRCLE_FILL, true);
+
   drawtoolbar->insertButton(BarIcon("ellipse"),ID_DRAW_ELLIPSE, TRUE, i18n("Draw ellipse"));
   drawtoolbar->setToggle(ID_DRAW_ELLIPSE, true);
+
   drawtoolbar->insertButton(BarIcon("filledellipse"),ID_DRAW_ELLIPSE_FILL, TRUE, i18n("Draw filled ellipse"));
   drawtoolbar->setToggle(ID_DRAW_ELLIPSE_FILL, true);
+
   drawtoolbar->insertButton(BarIcon("spraycan"),ID_DRAW_SPRAY, TRUE, i18n("Spray"));
   drawtoolbar->setToggle(ID_DRAW_SPRAY, true);
+  
   drawtoolbar->insertButton(BarIcon("flood"),ID_DRAW_FILL, TRUE, i18n("Flood fill"));
   drawtoolbar->setToggle(ID_DRAW_FILL, true);
-  drawtoolbar->setToggle(ID_DRAW_SPRAY, true);
+
   drawtoolbar->insertButton(BarIcon("eraser"),ID_DRAW_ERASE, TRUE, i18n("Erase"));
   drawtoolbar->setToggle(ID_DRAW_ERASE, true);
-    
+
   drawtoolbar->setIconText((KToolBar::IconText) pprops->drawtoolbartext);
   drawtoolbar->setBarPos(pprops->drawtoolbarpos);
+
   if(pprops->drawtoolbarstat)
-    drawtoolbar->enable(KToolBar::Show);
+    drawtoolbar->show();
   else
-    drawtoolbar->enable(KToolBar::Hide);
-  //drawtoolbar->show();
+    drawtoolbar->hide();
   connect( drawtoolbar, SIGNAL(clicked(int)), SLOT(slotTools(int)));
 
-  debug("setupDrawToolBar - done");
+  kdDebug() << "setupDrawToolBar - done" << endl;
   return true;
 }
 
 bool KIconEdit::setupPaletteToolBar()
 {
-  //Properties *pprops = props(this);
+    QWidget *sysColorsWidget = new QWidget(this);
+    QBoxLayout *ml = new QVBoxLayout(sysColorsWidget);
+    QLabel *l = new QLabel(i18n("System Colors"), sysColorsWidget);
+    syscolors = new KSysColors(sysColorsWidget);
+    syscolors->setFixedSize(syscolors->width(), syscolors->height());
+    ml->addWidget(l);
+    ml->addWidget(syscolors);
 
-  QWidget *w = new QWidget(this);
-  QBoxLayout *ml = new QVBoxLayout(w);
-  QLabel *l = new QLabel(i18n("System Colors"), w);
-  //l->setFixedSize(l->sizeHint());
-  syscolors = new KSysColors(w);
-  //syscolors->setFixedSize(syscolors->width(), syscolors->height());
-  ml->addWidget(l);
-  ml->addWidget(syscolors);
+    int ow = sysColorsWidget->sizeHint().width();
+    int iw = syscolors->width();
+    int ih = syscolors->height();
 
-  int ow = w->sizeHint().width();
-  int iw = syscolors->width();
+    palettetoolbar = new KToolBar(this, 0, ow+8);
+    CHECK_PTR(palettetoolbar);
+    addToolBar(palettetoolbar);
+    palettetoolbar->show();
+    palettetoolbar->setBarPos(KToolBar::Right);
 
-  palettetoolbar = new KToolBar(this, 0, ow+8);
-  CHECK_PTR(palettetoolbar);
-  addToolBar(palettetoolbar);
-  palettetoolbar->enable(KToolBar::Show);
-  palettetoolbar->setBarPos(KToolBar::Right);
+    sysColorsWidget->reparent(palettetoolbar, 0, QPoint(0, 0));
 
-  w->recreate(palettetoolbar, 0, QPoint(0, 0));
+    preview = new Preview(palettetoolbar);
+    preview->setFrameStyle(QFrame::Panel|QFrame::Sunken);
+    preview->setFixedSize(iw, 64); 
+    palettetoolbar->insertWidget(ID_PREVIEW, iw, preview);
+    palettetoolbar->insertSeparator();
 
-  preview = new Preview(palettetoolbar);
-  preview->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-  //preview->setFixedSize(iw, 60);
+    palettetoolbar->insertWidget(ID_SYSTEM_COLORS, iw, sysColorsWidget);
 
-  palettetoolbar->insertWidget(ID_PREVIEW, iw, preview);
-  palettetoolbar->insertSeparator();
-  palettetoolbar->insertWidget(ID_SYSTEM_COLORS, iw, w);
-  palettetoolbar->insertSeparator();
+    QWidget *customColorsWidget = new QWidget(palettetoolbar);
+    ml = new QVBoxLayout(customColorsWidget);
+    l = new QLabel(i18n("Custom Colors"), customColorsWidget);
+    customcolors = new KCustomColors(customColorsWidget);
+    customColorsWidget->setFixedSize(iw, 80);
+    ml->addWidget(l);
+    ml->addWidget(customcolors);
+    palettetoolbar->insertWidget(ID_CUSTOM_COLORS, iw, customColorsWidget);
 
-  w = new QWidget(palettetoolbar);
-  ml = new QVBoxLayout(w);
-  l = new QLabel(i18n("Custom Colors"), w);
-  //l->setFixedSize(l->sizeHint());
-  customcolors = new KCustomColors(w);
-  //customcolors->setFixedSize(iw, customcolors->height());
-  ml->addWidget(l);
-  ml->addWidget(customcolors);
-
-  palettetoolbar->insertWidget(ID_CUSTOM_COLORS, iw, w);
-
-  return true;
+    return true;
 }
 
 bool KIconEdit::setupStatusBar()
 {
-  Properties *pprops = props(this);
-  statusbar = new KStatusBar(this);
-  CHECK_PTR(statusbar);
-  setStatusBar(statusbar);
-  pprops->statusbar = statusbar;
+    Properties *pprops = props(this);
+    statusbar = statusBar();
+    CHECK_PTR(statusbar);
+    pprops->statusbar = statusbar;
 
-  statusbar->insertItem("    -1, -1    ", 0);
-  statusbar->insertItem("   32 x 32   ", 1);
-  statusbar->insertItem(" 1:1000 ", 2);
-  statusbar->insertItem("Colors:       ", 3);
-  statusbar->insertItem("", 4);
+    statusbar->insertItem("    -1, -1    ", 0);
+    statusbar->insertItem("   32 x 32   ", 1);
+    statusbar->insertItem(" 1:1000 ", 2);
+    statusbar->insertItem("Colors:       ", 3);
+    statusbar->insertItem("", 4);
 
-  if(pprops->statusbarstat)
-    statusbar->show();
-  else
-    statusbar->hide();
-  return true;
+    if(pprops->statusbarstat)
+        statusbar->show();
+    else
+        statusbar->hide();
+    return true;
 }
 
 bool KIconEdit::setupWhatsThis()
 { // QWhatsThis *what is created in setupToolbar
 
-  debug("setupWhatsThis");
+  kdDebug() << "setupWhatsThis" << endl;
 
   // Create help for the custom widgets
 
@@ -756,8 +703,8 @@ bool KIconEdit::setupWhatsThis()
   what->add(grid, str);
 
   str = i18n("Rulers\n\nThis is a visual represantation of the current cursor position");
-  what->add(gridview->hruler(), str.data());
-  what->add(gridview->vruler(), str.data());
+  what->add(gridview->hruler(), str);
+  what->add(gridview->vruler(), str);
 
   str = i18n("Statusbar\n\nThe statusbar gives information of the status "
              "of the current icon. The fields are:\n\n"
@@ -766,170 +713,170 @@ bool KIconEdit::setupWhatsThis()
              "\t- Zoom factor\n"
              "\t- Number of colors\n"
              "\t- Application messages");
-  what->add(statusbar, str.data());
+
+  what->add(statusbar, str);
 
   str = i18n("Preview\n\nThis is a 1:1 preview of the current icon");
-  what->add(preview, str.data());
+  what->add(preview, str);
 
   str = i18n("System colors\n\nHere you can select colors from the KDE Icon Palette.");
-  what->add(syscolors, str.data());
+  what->add(syscolors, str);
 
   str = i18n("Custom colors\n\nHere you can build a palette of custom colors.\n"
              "Just double-click on a box to edit the color");
-  what->add(customcolors, str.data());
+  what->add(customcolors, str);
 
   // Create help for the main toolbar
 
   str = i18n("New\n\nCreate a new icon either from a template or by specifying the size");
-  what->add(toolbar->getButton(ID_FILE_NEWFILE), str.data());
+  what->add(toolbar->getButton(ID_FILE_NEWFILE), str);
 
   str = i18n("Open\n\nOpen an existing icon");
-  what->add(toolbar->getButton(ID_FILE_OPEN), str.data());
+  what->add(toolbar->getButton(ID_FILE_OPEN), str);
 
   str = i18n("Save\n\nSave the current icon");
-  what->add(toolbar->getButton(ID_FILE_SAVE), str.data());
+  what->add(toolbar->getButton(ID_FILE_SAVE), str);
 
   str = i18n("Print\n\nOpens a print dialog to let you print the current icon."
              " (Doesn't realy work as expected");
-  what->add(toolbar->getButton(ID_FILE_PRINT), str.data());
+  what->add(toolbar->getButton(ID_FILE_PRINT), str);
 
   str = i18n("Cut\n\nCut the current selection out of the icon\n\n"
              "(Tip: You can make both rectangular and circular selections)");
-  what->add(toolbar->getButton(ID_EDIT_CUT), str.data());
+  what->add(toolbar->getButton(ID_EDIT_CUT), str);
 
   str = i18n("Copy\n\nCopy the current selection out of the icon\n\n"
              "(Tip: You can make both rectangular and circular selections)");
-  what->add(toolbar->getButton(ID_EDIT_COPY), str.data());
+  what->add(toolbar->getButton(ID_EDIT_COPY), str);
 
   str = i18n("Paste\n\nPaste the contents of the clipboard into the current icon.\n\n"
              "If the contents is larger than the current icon you can paste it"
              " in a new window.\n\n"
              "(Tip: Select \"Paste transparent pixels\" in the configuration dialog"
              " if you also want to paste transparent)");
-  what->add(toolbar->getButton(ID_EDIT_PASTE), str.data());
+  what->add(toolbar->getButton(ID_EDIT_PASTE), str);
 
   str = i18n("Select\n\nSelect a section of the icon using the mouse.\n\n"
              "(Tip: You can make both rectangular and circular selections)");
-  what->add(toolbar->getButton(ID_SELECT), str.data());
+  what->add(toolbar->getButton(ID_SELECT), str);
 
   str = i18n("Resize\n\nSmoothly resizes the icon while trying to preserve the contents");
-  what->add(toolbar->getButton(ID_IMAGE_RESIZE), str.data());
+  what->add(toolbar->getButton(ID_IMAGE_RESIZE), str);
 
   str = i18n("Gray scale\n\nGray scale the current icon.\n"
              "(Warning: The result is likely to contain colors not in the icon palette");
-  what->add(toolbar->getButton(ID_IMAGE_GRAYSCALE), str.data());
+  what->add(toolbar->getButton(ID_IMAGE_GRAYSCALE), str);
 
   str = i18n("Zoom out\n\nZoom out by one.\n\n"
              "(Tip: Hold the button down for a few seconds to zoom to a predefined scale");
-  what->add(toolbar->getButton(ID_VIEW_ZOOM_OUT), str.data());
+  what->add(toolbar->getButton(ID_VIEW_ZOOM_OUT), str);
 
   str = i18n("Zoom in\n\nZoom in by one.\n\n"
              "(Tip: Hold the button down for a few seconds to zoom to a predefined scale");
-  what->add(toolbar->getButton(ID_VIEW_ZOOM_IN), str.data());
+  what->add(toolbar->getButton(ID_VIEW_ZOOM_IN), str);
 
   str = i18n("Toggle grid\n\nToggles the grid in the icon edit grid on/off");
-  what->add(toolbar->getButton(ID_OPTIONS_TOGGLE_GRID), str.data());
+  what->add(toolbar->getButton(ID_OPTIONS_TOGGLE_GRID), str);
 
   str = i18n("New window\n\nOpens a new Icon Editor window.");
-  what->add(toolbar->getButton(ID_FILE_NEWWIN), str.data());
-
-  str = i18n("Whats is...?\n\nWell since you're reading this I guess you found out ;-)");
-  what->add(toolbar->getButton(ID_HELP_WHATSTHIS), str.data());
-
-  str = i18n("Drag source\n\nFrom this button you can drag out a copy of the current icon"
-             " and drop it on a drop enabled window, eg. another Icon Editor.\n\n"
-             "(Note: The drag source uses the QT XDND protocol which is not"
-             " yet standard in KDE)");
-  what->add(dragbutton, str.data());
+  what->add(toolbar->getButton(ID_FILE_NEWWIN), str);
 
   // Setup help for the tools toolbar
 
   str = i18n("Free hand\n\nDraw non-linear lines");
-  what->add(drawtoolbar->getButton(ID_DRAW_FREEHAND), str.data());
+  what->add(drawtoolbar->getButton(ID_DRAW_FREEHAND), str);
 
   str = i18n("Flood fill\n\nFill adjoining pixels with the same color with the current color");
-  what->add(drawtoolbar->getButton(ID_DRAW_FILL), str.data());
+  what->add(drawtoolbar->getButton(ID_DRAW_FILL), str);
 
   str = i18n("Rectangle\n\nDraw a rectangle");
-  what->add(drawtoolbar->getButton(ID_DRAW_RECT), str.data());
+  what->add(drawtoolbar->getButton(ID_DRAW_RECT), str);
 
   str = i18n("Filled rectangle\n\nDraw a filled rectangle");
-  what->add(drawtoolbar->getButton(ID_DRAW_RECT_FILL), str.data());
+  what->add(drawtoolbar->getButton(ID_DRAW_RECT_FILL), str);
 
   str = i18n("Circle\n\nDraw a circle");
-  what->add(drawtoolbar->getButton(ID_DRAW_CIRCLE), str.data());
+  what->add(drawtoolbar->getButton(ID_DRAW_CIRCLE), str);
 
   str = i18n("Filled circle\n\nDraw a filled circle");
-  what->add(drawtoolbar->getButton(ID_DRAW_CIRCLE_FILL), str.data());
+  what->add(drawtoolbar->getButton(ID_DRAW_CIRCLE_FILL), str);
 
   str = i18n("Ellipse\n\nDraw an ellipse");
-  what->add(drawtoolbar->getButton(ID_DRAW_ELLIPSE), str.data());
+  what->add(drawtoolbar->getButton(ID_DRAW_ELLIPSE), str);
 
   str = i18n("Filled ellipse\n\nDraw a filled ellipse");
-  what->add(drawtoolbar->getButton(ID_DRAW_ELLIPSE_FILL), str.data());
+  what->add(drawtoolbar->getButton(ID_DRAW_ELLIPSE_FILL), str);
 
   str = i18n("Line\n\nDraw a straight line vertically, horizontically or in 45 dgr. angles");
-  what->add(drawtoolbar->getButton(ID_DRAW_LINE), str.data());
+  what->add(drawtoolbar->getButton(ID_DRAW_LINE), str);
 
   str = i18n("Spray\n\nDraw scattered pixels in the current color");
-  what->add(drawtoolbar->getButton(ID_DRAW_SPRAY), str.data());
+  what->add(drawtoolbar->getButton(ID_DRAW_SPRAY), str);
 
   str = i18n("Find\n\nThe color of the pixel clicked on will be the current drawcolor");
-  what->add(drawtoolbar->getButton(ID_DRAW_FIND), str.data());
+  what->add(drawtoolbar->getButton(ID_DRAW_FIND), str);
 
   str = i18n("Erase\n\nErase pixels. Set the pixels to be transparent\n\n"
              "(Tip: If you want to draw transparent with a different tool"
              " then first click on \"Erase\" then on the tool you want to use)");
-  what->add(drawtoolbar->getButton(ID_DRAW_ERASE), str.data());
+  what->add(drawtoolbar->getButton(ID_DRAW_ERASE), str);
 
-  debug("setupWhatsThis - done");
+  kdDebug() << "setupWhatsThis - done" << endl;
   return true;
 }
 
-void KIconEdit::addRecent(const char *filename)
+void KIconEdit::addRecent(const QString & path)
 {
-  QString str = filename;
-  //debug("addRecent - checking %s", filename);
-  Properties *pprops = props(this);
-  if(str.isEmpty() || pprops->recentlist->contains(filename))
-    return;
-  //debug("addRecent - adding %s", filename);
+    QString pathStr = path;
 
-  if( pprops->recentlist->count() < 5)
-    pprops->recentlist->insert(0,filename);
-  else
-  {
-    pprops->recentlist->remove(4);
-    pprops->recentlist->insert(0,filename);
-  }
+    kdDebug() << "KIconEdit::addRecent() - checking " << pathStr << endl;
+    Properties *pprops = props(this);
+    if(pathStr.isEmpty() || pprops->recentlist->contains(pathStr))
+        return;
 
-  recent->clear();
+    kdDebug() << "KIconEdit::addRecent() - adding to pprops->recentlist " << pathStr << endl;
+    if( pprops->recentlist->count() < 5)
+    {
+        pprops->recentlist->prepend(pathStr);
+    }    
+    else
+    {
+        pprops->recentlist->remove(pprops->recentlist->at(4));
+        pprops->recentlist->prepend(pathStr);
+    }
+    kdDebug() << "KIconEdit::addRecent() - adding to pprops->recentlist- done " << path << endl;
+    recent->clear();
 
-  for ( int i = 0 ;i < (int)pprops->recentlist->count(); i++)
-    recent->insertItem(pprops->recentlist->at(i));
+    kdDebug() << "KIconEdit::addRecent() - adding to recent " << path << endl;
+    for ( int i = 0 ;i < (int)pprops->recentlist->count(); i++)
+        recent->insertItem(*pprops->recentlist->at(i));
+        
+    kdDebug() << "KIconEdit::addRecent() - adding to recent - done" << path << endl;
 
-  file->setItemEnabled(ID_FILE_RECENT, true);
-  //debug("addRecent - done");
+    file->setItemEnabled(ID_FILE_RECENT, true);
+    kdDebug() << "addRecent - done" << endl;
 }
 
+
 void KIconEdit::toggleTool(int id)
 {
   for(int i = ID_DRAW_FREEHAND; i <= ID_DRAW_ERASE; i++)
   {
-    if(i != id)
-    {
-      if(tools->isItemChecked(i))
-        tools->setItemChecked(i, false);
-      if(drawtoolbar->isButtonOn(i));
-        drawtoolbar->setButton(i, false);
+        if(i != id)
+        {
+        if(tools->isItemChecked(i))
+            tools->setItemChecked(i, false);
+        if(drawtoolbar->isButtonOn(i));
+            drawtoolbar->setButton(i, false);
         //((KToolBarButton*)drawtoolbar->getButton(i))->on(false);
     }
     else
     {
-      tools->setItemChecked(i, true);
-      if(!drawtoolbar->isButtonOn(i));
+        tools->setItemChecked(i, true);
+        if(!drawtoolbar->isButtonOn(i));
         //((KToolBarButton*)drawtoolbar->getButton(i))->on(true);
-        drawtoolbar->setButton(i, true);
+            drawtoolbar->setButton(i, true);
     }
   }
 }
+#include "kiconedit.moc"
