@@ -31,12 +31,13 @@
 #include <qtimer.h>
 
 #include <kapp.h>
-#include <ktmainwindow.h>
+#include <kmainwindow.h>
 #include <kiconloader.h>
 #include <kmenubar.h>
 #include <kstatusbar.h>
 #include <ktoolbar.h>
 #include <kaccel.h>
+#include <kurl.h>
 
 #include "kicontools.h"
 #include "knew.h"
@@ -44,10 +45,9 @@
 #include "kiconconfig.h"
 #include "kicongrid.h"
 #include "kresize.h"
-#include "kdropsite.h"
 #include "properties.h"
 
-#include <kwm.h> /// last because it includes X headers
+#include <netwm.h>
 
 #define ID_FILE_NEWWIN  500
 #define ID_FILE_NEWFILE 501
@@ -108,7 +108,6 @@
 
 class QWhatsThis;
 class QToolButton;
-class KDragSource;
 
 /**
 * KIconEdit
@@ -116,7 +115,7 @@ class KDragSource;
 * @author Thomas Tanghus <tanghus@kde.org>
 * @version 0.4
 */
-class KIconEdit : public KTMainWindow
+class KIconEdit : public KMainWindow
 {
     Q_OBJECT
 public:
@@ -131,14 +130,13 @@ signals:
 public slots:
   virtual void saveProperties(KConfig*);
   virtual void readProperties(KConfig*);
-  void saveGoingDownStatus();
   void unsaved(bool flag);
 
 protected slots:
   void addColors(uint, uint*);
   void addColor(uint);
   void slotNewWin();
-  void slotNewWin(const char *url = 0);
+  void slotNewWin(const QString & url = 0);
   void slotNew();
   void slotOpen();
   void slotClose();
@@ -163,16 +161,16 @@ protected slots:
   void slotUpdateStatusPos(int, int);
   void slotUpdateStatusSize(int, int);
   void slotClearStatusMessage();
-  void slotUpdateStatusMessage(const char *);
-  void slotUpdateStatusName(const char *);
+  void slotUpdateStatusMessage(const QString &);
+  void slotUpdateStatusName(const QString &);
   void slotUpdateStatusScaling(int, bool);
   void slotUpdatePaste(bool);
   void slotUpdateCopy(bool);
   void slotOpenBlank(const QSize);
-
-  void slotQDropEvent( QDropEvent* );
-  void slotQDragLeaveEvent( QDragLeaveEvent* );
-  void slotQDragEnterEvent( QDragEnterEvent* );
+  void addRecent(const QString &);  
+  
+  virtual void dragEnterEvent(QDragEnterEvent* event);
+  virtual void dropEvent(QDropEvent *e);
 
 protected:
   void init();
@@ -186,7 +184,7 @@ protected:
   virtual void resizeEvent(QResizeEvent*);
   void writeConfig();
   void toggleTool(int id);
-  void addRecent(const char *file);
+
   void updateMenuAccel();
 
   KIconTemplateContainer *icontemplates;
@@ -199,13 +197,12 @@ protected:
   KMenuBar *menubar;
   KToolBar *toolbar, *drawtoolbar, *palettetoolbar;
   KStatusBar *statusbar;
-  QPopupMenu *edit, *file, *view, *image, *help, *tools, *options, *zoom, *recent, *select;
+  QPopupMenu *edit, *file, *view, *image, *help;
+  QPopupMenu *tools, *options, *zoom, *recent, *select;
   KIconEditGrid *grid;
   QTimer *msgtimer;
   KGridView *gridview;
   KIconEditIcon *icon;
-  KDropSite *dropsite;
-  KDragSource *dragbutton;
   KIconEditProperties *kiprops;
   QWhatsThis *what;
   QImage img;
