@@ -26,6 +26,8 @@
 
 #include <kseparator.h>
 #include <klocale.h>
+#include <kdebug.h>
+
 #include "kwizard.h"
 
 
@@ -59,7 +61,7 @@ KWizard::KWizard(QWidget *parent, const char *name, bool modal, WFlags f)
   : KDialog(parent, name, modal, f)
 //  : QWidget(parent, name, modal ? (f | WType_Modal) : f)
 {
-  //debug("KWizard creation");
+  //kdDebug() << "KWizard creation" << endl;
 
   initMetaObject();
 
@@ -107,18 +109,18 @@ KWizard::KWizard(QWidget *parent, const char *name, bool modal, WFlags f)
 
   installEventFilter(this);
 
-  //debug("KWizard created");
+  //kdDebug() << "KWizard created" << endl;
 }
 
 // Destructor
 KWizard::~KWizard()
 {
-  //debug("KWizard - destructor");
+  //kdDebug() << "KWizard - destructor" << endl;
   //if (menu) delete menu;
   //menu = 0L;
   delete pwiz;
   delete pages;
-  //debug("KWizard - destructor done");
+  //kdDebug() << "KWizard - destructor done" << endl;
 }
 
 void KWizard::setCancelButton(const QString& name)
@@ -239,7 +241,7 @@ KDirectionButton *KWizard::getRightArrow()
 
 QSize KWizard::pageSize()
 {
-  //debug("Calculating sizes");
+  //kdDebug() << "Calculating sizes" << endl;
   QSize size(0,0);
   //int x = 0, y = 0;
   for(int i = 0; i < pwiz->numpages; i++)
@@ -249,7 +251,7 @@ QSize KWizard::pageSize()
       size.setHeight(csize.height());
     if(size.width() < csize.width())
       size.setWidth(csize.width());
-    //debug("Page size: %d x %d", size.width(), size.height());
+    //kdDebug() << "Page size: " << size.width() << " x " << size.height() << endl;
   }
 
   return size;
@@ -257,15 +259,15 @@ QSize KWizard::pageSize()
 
 void KWizard::setSizes()
 {
-  //debug("setSizes");
+  //kdDebug() << "setSizes" << endl;
   QFont titlefont;
   //titlefont.setPointSize(titlefont.pointSize()*2);
   titlefont.setWeight(QFont::Bold);
   pwiz->title->setFont(titlefont);
   pwiz->title->adjustSize();
 
-  //debug("Title points: %d", titlefont.pointSize());
-  //debug("Title height: %d", title->height());
+  //kdDebug() << "Title points: " << titlefont.pointSize() << endl;
+  //kdDebug() << "Title height: " << title->height() << endl;
 
   pwiz->pagina->adjustSize();
 
@@ -307,7 +309,7 @@ void KWizard::setSizes()
 void KWizard::resizeEvent(QResizeEvent *)
 {
   //QSize pagesize = pageSize();
-  //debug("KWizard, resizeEvent()");
+  //kdDebug() << "KWizard, resizeEvent()" << endl;
 
   int subtr = 4;
   if(pwiz->ok && pwiz->ok->isVisible())
@@ -320,7 +322,7 @@ void KWizard::resizeEvent(QResizeEvent *)
     subtr = pwiz->help->height() + 10;
 
   //main->setGeometry(2, 2, width()-4, height()-(subtr));
-  //debug("main");
+  //kdDebug() << "main" << endl;
   //pagina->adjustSize();
 
   pwiz->title->setGeometry(7, 7,
@@ -347,12 +349,12 @@ void KWizard::resizeEvent(QResizeEvent *)
   else
     pwiz->pagina->hide();
 
-  //debug("header - pagina: %d", pagina->width());
+  //kdDebug() << "header - pagina: " << pagina->width() << endl;
   pwiz->sep1->setGeometry(7,
                           pwiz->title->height()+10,
                           width()-14,
                           2);
-  //debug("sep1");
+  //kdDebug() << "sep1" << endl;
 
   if(pwiz->currentwidget)
   {
@@ -362,8 +364,8 @@ void KWizard::resizeEvent(QResizeEvent *)
     pwiz->currentwidget->setGeometry( 7, offs, width()-14,
            height()-( pwiz->next->height() + 40 + subtr + hack));
   }
-  else debug("No currentwidget!");
-  //debug("currentwidget");
+  else kdDebug() << "No currentwidget!" << endl;
+  //kdDebug() << "currentwidget" << endl;
   if(pwiz->directionsreflectspage)
   {
     QString str;
@@ -388,7 +390,7 @@ void KWizard::resizeEvent(QResizeEvent *)
 
   pwiz->sep2->setGeometry(7, height()-(pwiz->next->height()+14+subtr),
                     width()-14, 2);
-  //debug("sep2");
+  //kdDebug() << "sep2" << endl;
   pwiz->next->adjustSize();
   pwiz->previous->adjustSize();
   pwiz->next->move(width()-(pwiz->next->width()+7),
@@ -417,7 +419,7 @@ void KWizard::resizeEvent(QResizeEvent *)
                             height()-(pwiz->help->height()+2),
                             pwiz->help->width(), pwiz->cancel->height());
 
-  //debug("KWizard, resizeEvent done");
+  //kdDebug() << "KWizard, resizeEvent done" << endl;
 }
 
 void KWizard::paintEvent(QPaintEvent *)
@@ -458,10 +460,10 @@ int KWizard::addPage(KWizardPage *p)
 {
   CHECK_PTR(p->w);
 
-  p->w->recreate(this, 0, QPoint(0, 0));
-  //debug("recreated");
+  p->w->reparent(this, 0, QPoint(0, 0));
+  //kdDebug() << "recreated" << endl;
   p->w->hide();
-  //debug("hidden");
+  //kdDebug() << "hidden" << endl;
   if(pwiz->numpages == 0)
   {
     pwiz->current = 0;
@@ -477,7 +479,7 @@ int KWizard::addPage(KWizardPage *p)
   pwiz->numpages++;
   pwiz->menu->insertItem(p->title, p->id);
   pwiz->menu->setItemEnabled(p->id, p->enabled);
-  //debug("inserted menuitem");
+  //kdDebug() << "inserted menuitem" << endl;
   pages->append(p);
   //titles.append(strtitle);
 
@@ -497,15 +499,15 @@ int KWizard::addPage(KWizardPage *p)
     }
   }
 
-  //debug("enabled buttons");
+  //kdDebug() << "enabled buttons" << endl;
   QString strpagina = i18n("Page %1 of %2").arg(pwiz->current+1).arg(pwiz->numpages);
   if(pwiz->numpages > 1)
     pwiz->pagina->setText(strpagina);
   else
     pwiz->pagina->setText("");
-  //debug("pagina");
+  //kdDebug() << "pagina" << endl;
   setSizes();
-  //debug("Add page, done");
+  //kdDebug() << "Add page, done" << endl;
 
   return (p->id);
 }
@@ -602,12 +604,12 @@ int KWizard::numPages()
 
 void KWizard::gotoPage(int p)
 {
-  //debug("gotopage: %d", p);
+  //kdDebug() << "gotopage: " << p << endl;
 
   if(p >= pwiz->numpages) // || p == pwiz->current)
     return;
 
-  //debug("Changing to page %d", p);
+  //kdDebug() << "Changing to page " << p << endl;
 
   if(p < (pwiz->numpages-1))
   {
@@ -689,7 +691,7 @@ bool KWizard::eventFilter( QObject *obj, QEvent *e )
     QMouseEvent *m = (QMouseEvent*)e;
     if(pwiz->title->rect().contains( m->pos()) && m->button() == RightButton)
     {
-      //debug("KWizard::eventFilter() - inside");
+      //kdDebug() << "KWizard::eventFilter() - inside" << endl;
       emit popup(mapToGlobal(m->pos()));
       if(!pwiz->enablepopupmenu)
         return false;
@@ -703,13 +705,13 @@ bool KWizard::eventFilter( QObject *obj, QEvent *e )
     QKeyEvent *k = (QKeyEvent*)e;
     if(k->key() == Key_PageUp)
     {
-      //debug("Received keyevent PageUp");
+      //kdDebug() << "Received keyevent PageUp" << endl;
       previousPage();
       return true;
     }
     else if(k->key() == Key_PageDown)
     {
-      //debug("Received keyevent PageDown");
+      //kdDebug() << "Received keyevent PageDown" << endl;
       nextPage();
       return true;
     }
@@ -748,3 +750,4 @@ QSize KWizard::sizeHint()
   s.setHeight(s.height() + h);
   return s;
 }
+#include "kwizard.moc"
