@@ -1,4 +1,4 @@
-/*  
+/*
     kiconedit - a small graphics drawing program the KDE.
 
     Copyright (C) 1998 Thomas Tanghus (tanghus@kde.org)
@@ -17,7 +17,7 @@
     along with this library; see the file COPYING.LIB.  If not, write to
     the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
-*/  
+*/
 
 #ifndef __PROPS_H__
 #define __PROPS_H__
@@ -39,9 +39,9 @@ class KIconEditProperties;
 struct Properties
 {
   KAccel *keys;
-  QDict<KKeyEntry> keydict;
+  KKeyEntryMap keydict;
   QList<KIconTemplate> *tlist;
-  QStrList *recentlist;
+  QStringList *recentlist;
   QString backgroundpixmap;
   QColor backgroundcolor;
   QWidget::BackgroundMode backgroundmode;
