@@ -1,4 +1,4 @@
-// $Id: canvas.cpp,v 1.20 2000/06/05 11:04:59 hoelzer Exp $
+// $Id: canvas.cpp,v 1.25 2000/12/21 04:04:38 jcaliff Exp $
 
 #include <kdebug.h>
 #include <stdio.h>
@@ -8,21 +8,21 @@
 #include <qpainter.h>
 #include <qimage.h>
 #include <qwmatrix.h>
+#include <qclipboard.h>
+
 #include <klocale.h>
 #include <kapp.h>
+
 #include <math.h>
+
 #include "canvas.h"
 #include "tool.h"
 
 #define CUT_FILL_RGB 0xFFFFFF //white
 
-// static initialisers
-// can't construct a pixmap before qapplication
-QPixmap *Canvas::clipboardPix = NULL;
 int Canvas::inst = 0;
 
-Canvas::Canvas(int width, int height,
-	       QWidget *parent, const char *name)
+Canvas::Canvas(int width, int height, QWidget *parent, const char *name)
   : QWidget(parent, name)
 {
   currentTool= 0;
@@ -33,7 +33,7 @@ Canvas::Canvas(int width, int height,
   // Create pixmap
   pix= new QPixmap(width, height);
   if (!pix) {
-    kdDebug(3000) << "Canvas::Canvas(): Cannot create pixmap\n" << endl;
+    kdDebug(4400) << "Canvas::Canvas(): Cannot create pixmap\n" << endl;
     exit(1);
   }
 
@@ -44,16 +44,12 @@ Canvas::Canvas(int width, int height,
   // Set keyboard focus policy
   setFocusPolicy(QWidget::StrongFocus);
   emit sizeChanged();
-  
-  if ((0 == inst) && (NULL == Canvas::clipboardPix)) {
-    debug("install clipboard");
-    Canvas::clipboardPix = new QPixmap;
-  }
+
   Canvas::inst++;
   
 }
 
-Canvas::Canvas(const char *filename, QWidget *parent, const char *name)
+Canvas::Canvas(const QString & filename, QWidget *parent, const char *name)
   : QWidget(parent, name)
 {
   currentTool= 0;
@@ -63,8 +59,9 @@ Canvas::Canvas(const char *filename, QWidget *parent, const char *name)
 
   // Create pixmap
   pix= new QPixmap(filename);
-  if (!pix) {
-    kdDebug(3000) << "Canvas::Canvas(): Cannot create pixmap\n" << endl;
+  if (!pix) 
+  {
+    kdDebug(4400) << "Canvas::Canvas(): Cannot create pixmap\n" << endl;
     exit(1);
   }
 
@@ -76,11 +73,7 @@ Canvas::Canvas(const char *filename, QWidget *parent, const char *name)
 
   // Set keyboard focus policy
   setFocusPolicy(QWidget::StrongFocus);
-  
-  if ((0 == inst) && (NULL == Canvas::clipboardPix)) {
-    debug("install clipboard");
-    Canvas::clipboardPix = new QPixmap;
-  }
+ 
   Canvas::inst++;
   
 }
@@ -98,47 +91,46 @@ Canvas::~Canvas()
 
 bool Canvas::isModified()
 {
-  return modified_;
+    return modified_;
 }
 
 void Canvas::clearModified()
 {
-  modified_= false;
+    modified_= false;
 }
 
 void Canvas::markModified()
 {
-  if (!modified_) {
     modified_= true;
-    kdDebug(3000) << "Canvas: emitting modified()\n" << endl;
-  }
-  emit modified();
+    kdDebug(4400) << "Canvas: emitting modified()\n" << endl;
+    emit modified();
 }
 
 void Canvas::setSelection(const QRect &rect)
 {
-  selection_= rect;
-  haveSelection_= true;
-  emit selection(true);
+    selection_= rect;
+    haveSelection_= true;
+    emit selection(true);
 }
 
 const QRect &Canvas::selection()
 {
-  return selection_;
+    return selection_;
 }
 
 void Canvas::clearSelection()
 {
-  haveSelection_= false;
-  selection_= QRect(0,0,0,0);
-  emit selection(false);
+    haveSelection_= false;
+    selection_= QRect(0,0,0,0);
+    emit selection(false);
 }
 
 QPixmap *Canvas::selectionData()
 {
   QPixmap *p;
 
-  if (haveSelection_) {
+  if (haveSelection_) 
+  {
     p= new QPixmap(selection_.width(), selection_.height());
     bitBlt(p, 0, 0, pix,
 	   selection_.left(), selection_.top(),
@@ -153,41 +145,67 @@ QPixmap *Canvas::selectionData()
 
 // -------- CUT / COPY / PASTE ------------
 
-/* currently not implemented */
 void 
 Canvas::cut()
 {
   if (haveSelection_) {
+
+    const QColor c((QRgb)CUT_FILL_RGB);
+    
     // copy the selection and fill the 
     // copied rect with CUT_FILL_RGB, mostly white, see definition above
-    copy();
-    const QColor c((QRgb)CUT_FILL_RGB);
+    
+    copy(true);
     QPixmap p(selection_.size());
-    p.fill(c);
-    bitBlt(pix, selection_.topLeft(), &p, selection_, CopyROP);    
+
+    //p.fill(c);
+    p.fill(QColor("white"));
+    
+    bitBlt(pix, selection_.left(), selection_.top(), 
+           &p, 0, 0, p.width(), p.height(), CopyROP);
+           
+    clearSelection();
+    markModified();
+    updateZoomed();
+    repaint(0);
   }
 }
 
 
 void 
-Canvas::copy()
+Canvas::copy(bool andCut)
 {
-  if (haveSelection_) {
-    Canvas::clipboardPix->resize(selection_.size());
-    const QPoint p(0,0);
-    bitBlt(Canvas::clipboardPix, p, pix, selection_, CopyROP);
-    clearSelection();
+  if (haveSelection_) 
+  {
+    int left = selection_.left();
+    int top  = selection_.top();
+    int wid  = selection_.right() - selection_.left();
+    int hgt  = selection_.bottom() - selection_.top();
+    
+    kdDebug(0) << "left: " << left << " top: " << top << " wid: " << wid << " hgt: " << hgt << endl;   
+
+    clipboardPix.resize(wid, hgt);    
+    bitBlt(&clipboardPix, 0, 0, pix, left, top, wid, hgt, CopyROP);
+    kapp->clipboard()->setPixmap(clipboardPix); 
+    
+    if(!andCut) clearSelection();
     emit clipboard(true);
   }
 }
 
+
 void
 Canvas::paste()
 {
-#warning "paste not implemented"
-  warning("paste from clipboard not implemented");
-  
-  clearSelection();
+    if(100 != zoom())
+    {
+        kdDebug(0) << "Cut/Copy/Paste not implemented in zoom mode!" << endl;
+    }	
+
+    bitBlt(pix, 0, 0, &clipboardPix, 
+        0, 0, clipboardPix.width(), clipboardPix.height() , CopyROP);  
+
+    markModified();
 }
 
 
@@ -238,6 +256,51 @@ void Canvas::updateZoomed()
   repaint(0);
 }
 
+/*
+    The offscreen clipboard pixmap must also be adjusted to
+    zoom factor for pasting to a zoomed canvas pixmap
+*/
+
+void Canvas::updateZoomedClipboard()
+{
+  if (!clipboardPix.isNull())
+  {      
+    QPainter p;
+
+    int clipWid = clipboardPix.width();
+    int clipHgt = clipboardPix.height();
+    
+    int newClipWid = (int) (clipWid * ((float) zoomFactor/100));
+    int newClipHgt = (int) (clipHgt * ((float) zoomFactor/100));
+        
+    /* make copy of clipboard data to temporary pixmap */
+    QPixmap *zc = new QPixmap(clipWid, clipHgt);    
+    zc->fill(QColor("white"));
+    p.begin(zc);
+    p.drawPixmap(0,0, clipboardPix);
+    p.end();
+
+    /* adjust clipboard size to zoom factor */
+    clipboardPix.resize(QSize(newClipWid, newClipHgt));
+    clipboardPix.fill(QColor("white"));
+
+    /* copy to adjusted clipboard using matrix */
+    p.begin(&clipboardPix);
+    p.setWorldMatrix(*matrix);
+    p.drawPixmap(0,0,*zc);
+    p.end();
+    
+    /* clean up */
+    delete zc;
+  }
+}
+
+bool Canvas::hasClipboardData()
+{
+    QPixmap cPixmap = kapp->clipboard()->pixmap();
+    return (cPixmap.isNull() ? false : true);
+}
+
 int Canvas::zoom()
 {
   return zoomFactor;
@@ -269,29 +332,30 @@ QPixmap *Canvas::zoomedPixmap()
 
 void Canvas::setPixmap(QPixmap *px)
 {
-  QPainter p;
-  int w, h;
+    QPainter p;
+    int w, h;
 
-  *pix= *px;
-  emit pixmapChanged(pix);
+    *pix= *px;
+    emit pixmapChanged(pix);
 
-  delete zoomed;
+    delete zoomed;
 
-  w= (int) (px->width()* ((float) zoomFactor/100));
-  h= (int) (px->height()*((float) zoomFactor/100));
+    w = (int) (px->width()* ((float) zoomFactor/100));
+    h = (int) (px->height()*((float) zoomFactor/100));
 
-  zoomed= new QPixmap(w, h);
+    zoomed = new QPixmap(w, h);
 
-  p.begin(zoomed);
-  p.setWorldMatrix(*matrix);
-  p.drawPixmap(0,0,*pix);
-  p.end();
+    p.begin(zoomed);
+    p.setWorldMatrix(*matrix);
+    p.drawPixmap(0,0,*pix);
+    p.end();
 
-  if ((w != width()) || (h != height())) {
-    resize(w,h);
-    emit sizeChanged();
-  }
-  repaint(0);
+    if ((w != width()) || (h != height())) 
+    {
+        resize(w,h);
+        emit sizeChanged();
+    }
+    repaint(0);
 }
 
 void Canvas::setDepth(int d)
@@ -310,6 +374,7 @@ void Canvas::setDepth(int d)
     *px= i;
     setPixmap(px);
     emit pixmapChanged(px);
+    markModified();
     delete px;
   }
 }
@@ -331,10 +396,17 @@ void Canvas::resizeImage(int w, int h)
     pix= newpix;
     setZoom(zoom());
     emit pixmapChanged(pix);
+    markModified();
   }
   repaint(0);
 }
 
+/* 
+    paint Event is the ONLY place where the canvas is
+    updated, normally, by copying the offscreen zoomed pixmap
+    to the canvas    
+*/
+
 void Canvas::paintEvent(QPaintEvent *)
 {
   bitBlt(this, 0, 0, zoomed);
@@ -342,7 +414,7 @@ void Canvas::paintEvent(QPaintEvent *)
 
 void Canvas::mousePressEvent(QMouseEvent *e)
 {
-kdDebug(3000) << "Canvas::mousePressEvent() redirector called\n" << endl;
+kdDebug(4400) << "Canvas::mousePressEvent() redirector called\n" << endl;
   if (isActive())
     currentTool->mousePressEvent(e);
 } 
@@ -355,7 +427,7 @@ void Canvas::mouseMoveEvent(QMouseEvent *e)
 
 void Canvas::mouseReleaseEvent(QMouseEvent *e)
 {
-kdDebug(3000) << "Canvas::mouseReleaseEvent() redirector called\n" << endl;
+kdDebug(4400) << "Canvas::mouseReleaseEvent() redirector called\n" << endl;
   if (isActive())
     currentTool->mouseReleaseEvent(e);
 }
@@ -368,19 +440,23 @@ bool Canvas::isActive()
     return false;
 }
 
-bool Canvas::load(const char *filename, const char *format)
+bool Canvas::load(const QString & filename, const char *format)
 {
   bool s;
   QPixmap p;
   QPixmap q; // Fix UMR when reading transparent pixels (they hold junk)
 
-  if (!format) { // format == NULL
-    s= p.load(filename);
-  } else {
-    s= p.load(filename, format);
+  if (!format) 
+  { 
+    s = p.load(filename);
+  } 
+  else 
+  {
+    s = p.load(filename, format);
   }
 
-  if (s) {
+  if (s) 
+  {
     q.resize(p.size());
     q.fill(QColor("white"));
     bitBlt(&q, 0, 0, &p);
@@ -393,22 +469,22 @@ bool Canvas::load(const char *filename, const char *format)
   return s;
 }
 
-bool Canvas::save(const char *filename, const char *format)
+bool Canvas::save(const QString & filename, const char *format)
 {
   bool s;
 
-kdDebug(3000) << "Canvas::save() file= " << filename << ", format= " << format << "\n" << endl;
+kdDebug(4400) << "Canvas::save() file= " << filename << ", format= " << format << "\n" << endl;
 
   s= pix->save(filename, format);
 
-kdDebug(3000) << "Canvas::save() returning " << s << "\n" << endl;
+kdDebug(4400) << "Canvas::save() returning " << s << "\n" << endl;
 
   return s;
 }
 
 void Canvas::keyPressEvent(QKeyEvent *e)
 {
-  //kdDebug(3000) << "Canvas::keyPressEvent() redirector called\n" << endl;
+  //kdDebug(4400) << "Canvas::keyPressEvent() redirector called\n" << endl;
   if (isActive())
     currentTool->keyPressEvent(e);
 }
@@ -416,7 +492,7 @@ void Canvas::keyPressEvent(QKeyEvent *e)
 
 void Canvas::keyReleaseEvent(QKeyEvent *e)
 {
-  //kdDebug(3000) << "Canvas::keyReleaseEvent() redirector called\n" << endl;
+  //kdDebug(4400) << "Canvas::keyReleaseEvent() redirector called\n" << endl;
   if (isActive())
     currentTool->keyReleaseEvent(e);
 }
