@@ -1,4 +1,4 @@
-// $Id: canvassize.h,v 1.5 1999/03/01 23:32:07 kulow Exp $
+// $Id: canvassize.h,v 1.7 2000/11/27 14:06:02 mlaurent Exp $
 
 #ifndef CANVASSIZE_H
 #define CANVASSIZE_H
@@ -7,11 +7,13 @@
 #include <qlabel.h>
 #include <qlineedit.h>
 #include <qpushbutton.h>
+#include <qcheckbox.h>
 
 class canvasSizeDialog : public QDialog
 {
+  Q_OBJECT
 public:
-  canvasSizeDialog(QWidget *parent=0, const char *name= 0);
+  canvasSizeDialog(QWidget *parent=0, const char *name= 0,int _width=0,int _height=0);
   int getWidth();
   int getHeight();
 private:
@@ -21,6 +23,13 @@ private:
   QLineEdit *heightEdit;
    QPushButton *okButton;
    QPushButton *cancelButton;
+   QCheckBox *pictureRatio;
+   int width;
+   int height;
+public slots:
+   void slotWidthTextChanged(const QString &);
+   void changeState();
+
 };
 
 #endif // CANVASSIZE_H
