@@ -1,4 +1,4 @@
-// $Id: circle.cpp,v 1.21 2000/06/05 11:04:59 hoelzer Exp $
+// $Id: circle.cpp,v 1.24 2000/11/25 10:06:51 mlaurent Exp $
 
 #include <kdebug.h>
 #include <stdio.h>
@@ -19,7 +19,7 @@ Circle::Circle() : Tool()
   props= Tool::HasLineProperties | Tool::HasFillProperties;
 }
 
-Circle::Circle(const char *toolname) : Tool(toolname)
+Circle::Circle(const QString & toolname) : Tool(toolname)
 {
   drawing= FALSE;
   tooltip= i18n("Circle");
@@ -28,18 +28,18 @@ Circle::Circle(const char *toolname) : Tool(toolname)
 
 void Circle::activating()
 {
-kdDebug(3000) << "Circle::activating() hook called\n" << endl;
+kdDebug(4400) << "Circle::activating() hook called\n" << endl;
 
   canvas->setCursor(crossCursor);
 }
 
 void Circle::mousePressEvent(QMouseEvent *e)
 {
-kdDebug(3000) << "Circle::mousePressEvent() handler called\n" << endl;
+kdDebug(4400) << "Circle::mousePressEvent() handler called\n" << endl;
   
   if (isActive()) {
     if (drawing) {
-      kdDebug(3000) << "Circle: Warning button press received while drawing\n" << endl;
+      kdDebug(4400) << "Circle: Warning button press received while drawing\n" << endl;
     }
     else {
       startx= (e->pos()).x();
@@ -51,7 +51,7 @@ kdDebug(3000) << "Circle::mousePressEvent() handler called\n" << endl;
     }
   }
   if (!isActive()) {
-kdWarning(3000) << "Warning event received when inactive (ignoring)\n" << endl;
+kdWarning(4400) << "Warning event received when inactive (ignoring)\n" << endl;
   }
 }
 
@@ -108,7 +108,7 @@ void Circle::mouseMoveEvent(QMouseEvent *e)
     }
   }
   else {
-kdWarning(3000) << "Warning move event received when inactive (ignoring)\n" << endl;
+kdWarning(4400) << "Warning move event received when inactive (ignoring)\n" << endl;
   }
 }
 
@@ -119,10 +119,11 @@ void Circle::mouseReleaseEvent(QMouseEvent *e)
   QWMatrix m;
   int bbx, bby, r;
 
-kdDebug(3000) << "Circle::mouseReleaseEvent() handler called\n" << endl;
+kdDebug(4400) << "Circle::mouseReleaseEvent() handler called\n" << endl;
 
   if (isActive() && (e->button() == activeButton) && drawing) {
-    emit modified();
+    //emit modified();
+    canvas->markModified();
 
     x= (e->pos()).x();
     y= (e->pos()).y();
