@@ -1,12 +1,12 @@
 // -*- c++ -*-
 
-// $Id: infodialog.h,v 1.3 1998/01/13 19:01:57 rich Exp $
+// $Id: infodialog.h,v 1.4 1999/03/01 23:32:14 kulow Exp $
 
 #ifndef IMAGEINFODIALOG_H
 #define IMAGEINFODIALOG_H
 
 #include <qdialog.h>
-#include <qcombo.h>
+#include <qcombobox.h>
 #include <qlabel.h>
 #include "canvas.h"
 
