@@ -10,8 +10,6 @@ class View;
 class QScrollView;
 class Canvas;
 class QBoxLayout;
-class SideBar;
-class ColorBar;
 
 /**
  * view window for kpaint
@@ -25,8 +23,6 @@ MainView(QWidget *parent=0, const char *name=0);
 
   inline QScrollView *getViewport() const;
   inline Canvas *getCanvas() const;
-  inline SideBar * getSideBar() const;
-  inline ColorBar *getDefaultColorBar() const;
 
 private:
 
@@ -34,8 +30,6 @@ private:
   View *view;
   QScrollView *v;
   Canvas *c;
-  SideBar *side;
-  ColorBar *dcb;
 
   // Layoutmanager
   QBoxLayout *lm;
@@ -54,16 +48,4 @@ MainView::getCanvas() const
   return c;
 }
 
-SideBar *
-MainView::getSideBar() const
-{
-  return side;
-}
-
-ColorBar *
-MainView::getDefaultColorBar() const
-{
-  return dcb;
-}
-
 #endif // MAINVIEW_H
