@@ -1,4 +1,4 @@
-// $Id: manager.cpp,v 1.20 2000/06/05 11:04:59 hoelzer Exp $
+// $Id: manager.cpp,v 1.26 2000/12/31 13:23:18 jcaliff Exp $
 
 #include <kdebug.h>
 #include <qobject.h>
@@ -8,6 +8,8 @@
 #include <qpixmap.h>
 #include <klocale.h>
 #include <kstatusbar.h>
+#include <kcolorbtn.h>
+
 #include "manager.h"
 #include "commands.h"
 
@@ -19,37 +21,37 @@
 #include "roundangle.h"
 #include "spraycan.h"
 #include "areaselect.h"
+#include "brush.h"
 #include "text.h"
 
 Manager::Manager(Canvas *c)
  : QObject(), toolsToolBar(0L), statusBar(0L)
 {
-  
-  assert(c != 0);
-  assert(!(c->isActive()));
+    assert(c != 0);
+    assert(!(c->isActive()));
 
-  kdDebug(3000) << "Manager:: Constructing...\n" << endl;
+    kdDebug(4400) << "Manager:: Constructing...\n" << endl;
 
-  canvas= c;
-  createTools();
-  currentToolID= 0;
-  list.first()->activate(c);
+    canvas= c;
+    createTools();
+    currentToolID= 0;
+    list.first()->activate(c);
 
-  lmbCol= red;
-  rmbCol= green;
+    lmbCol= red;
+    rmbCol= green;
 
-  // Initialise the pens and brushes
-  p.setColor(lmbCol);
-  b.setColor(lmbCol);
-  list.first()->setLeftPen(p);
-  list.first()->setLeftBrush(b);
-  p.setColor(rmbCol);
-  b.setColor(rmbCol);
-  list.first()->setRightPen(p);
-  list.first()->setRightBrush(b);
+    // Initialise the pens and brushes
+    p.setColor(lmbCol);
+    b.setColor(lmbCol);
+    list.first()->setLeftPen(p);
+    list.first()->setLeftBrush(b);
+    p.setColor(rmbCol);
+    b.setColor(rmbCol);
+    list.first()->setRightPen(p);
+    list.first()->setRightBrush(b);
 
-  c->activate(list.first());
-  connect(this, SIGNAL(modified()), c, SLOT(markModified()));
+    c->activate(list.first());
+    connect(this, SIGNAL(modified()), c, SLOT(markModified()));
 }
 
 Manager::~Manager()
@@ -59,6 +61,8 @@ Manager::~Manager()
 void Manager::createTools()
 {
   AreaSelect *as; // handled different because of slot
+  PasteTool  *pt;
+  
   // Create the Tools
   list.setAutoDelete(TRUE);
   list.append(new Ellipse( i18n("Ellipse")));
@@ -77,14 +81,19 @@ void Manager::createTools()
   list.last()->id = 6;
   list.append(new Text( i18n("Text")));
   list.last()->id = 7;
+  
   as = new AreaSelect( i18n("Area Select"));
   connect(canvas, SIGNAL(selection(bool)),
 	  as, SLOT(selection(bool)));
   list.append(as);
   as->id = 8;
 
+  pt = new PasteTool( i18n("Paste"));
+  list.append(pt);
+  as->id = 9;
+
   // Create the properties dialog
-  props= new propertiesDialog(1, 0, i18n("Tool Properties"));
+  props= new propertiesDialog(1, 0, "tool_properties");
   connect(props, SIGNAL(applyButtonPressed()),
 	  this, SLOT(updateProperties()) );
 }
@@ -104,80 +113,93 @@ void Manager::updateProperties()
   list.at(currentToolID)->setRightBrush(b);
 }
 
+void Manager::setLMColorButton(KColorButton *cb)
+{
+    lmColorButton = cb;
+}
+
+void Manager::setRMColorButton(KColorButton *cb)
+{
+    rmColorButton = cb;
+}
+
 void Manager::setLMBcolour(const QColor &c)
 {
-warning("setLMBcolour\n");
+  kdWarning() << "setLMBcolour" << endl;
   lmbCol= c;
+  lmColorButton->setColor(c);
   updateProperties();
 }
 
 void Manager::setRMBcolour(const QColor &c)
 {
-warning("setRMBcolour\n");
+  kdWarning() << "setRMBcolour" << endl;
   rmbCol= c;
   updateProperties();
 }
 
+
 void Manager::setCurrentTool(int tool)
 {
-  /*
-  kdDebug(3000) << "got setCurrentTool " << tool << "\n" << endl;
-  kdDebug(3000) << " old Tool is " << currentToolID << "\n" << endl;
-  */
-  Tool *t;
 
-  if (currentToolID != tool) {
-    canvas->deactivate();
-    list.at(currentToolID)->deactivate();
-    currentToolID= tool;
-    t= list.at(tool);
-    t->activate(canvas);
+    /*
+    kdDebug(4400) << "got setCurrentTool " << tool << "\n" << endl;
+    kdDebug(4400) << " old Tool is " << currentToolID << "\n" << endl;
+    */
+    
+    Tool *t;
 
-    p.setColor(lmbCol);
-    b.setColor(lmbCol);
-    t->setLeftPen(p);
-    t->setLeftBrush(b);
-    p.setColor(rmbCol);
-    b.setColor(rmbCol);
-    t->setRightPen(p);
-    t->setRightBrush(b);
+    if (currentToolID != tool) 
+    {
+        canvas->deactivate();
+        list.at(currentToolID)->deactivate();
+        currentToolID= tool;
+        t= list.at(tool);
+        t->activate(canvas);
 
-    canvas->activate(t);
-    props->setPages(t->getPages());
-    props->repaint(0);
+        p.setColor(lmbCol);
+        b.setColor(lmbCol);
+        t->setLeftPen(p);
+        t->setLeftBrush(b);
+        p.setColor(rmbCol);
+        b.setColor(rmbCol);
+        t->setRightPen(p);
+        t->setRightBrush(b);
 
-    if (NULL != statusBar) {
-      statusBar->changeItem(t->getName(), ID_TOOL_NAME);
+        canvas->activate(t);
+        props->setPages(t->getPages());
+        props->repaint(0);
+
+        if (NULL != statusBar) 
+        {
+            statusBar->changeItem(t->getName(), ID_TOOL_NAME);
+        }
+        emit toolChanged(tool);
     }
-    emit toolChanged(tool);
-  }
 }
 
 
 void Manager::showPropertiesDialog()
 {
-  props->show();
+    props->show();
 }
 
 void Manager::populateToolbar(KToolBar *t)
 {
-  Tool *tool;
-  int i;
-  const char *tip;
+    Tool *tool;
+    int i;
+    QString tip;
 
-  toolsToolBar = t;
+    toolsToolBar = t;
 
-  for (i= 0, tool= list.first();
-       tool != 0;
-       i++, tool= list.next()) {
-    tip= tool->tip();
-    t->insertButton(tool->pixmap(), i, TRUE, tip, i);
-    tool->id= i;
-    /* ????????
-       connect(tool, SIGNAL(modified()), this, SIGNAL(modified())); */
-  }
-  t->setButton(currentToolID, true);
-  connect(t, SIGNAL(clicked(int)), SLOT(setCurrentTool(int)));
+    for(i= 0, tool= list.first(); tool != 0; i++, tool= list.next()) 
+    {
+        tip= tool->tip();
+        t->insertButton(tool->pixmap(), i, TRUE, tip, i);
+        tool->id= i;
+    }
+    t->setButton(currentToolID, true);
+    connect(t, SIGNAL(clicked(int)), SLOT(setCurrentTool(int)));
 }
 
 #include "manager.moc"
