@@ -1,4 +1,4 @@
-// $Id: pen.cpp,v 1.21 2000/06/05 11:04:59 hoelzer Exp $
+// $Id: pen.cpp,v 1.24 2000/11/25 10:06:51 mlaurent Exp $
 
 #include <kdebug.h>
 #include <stdio.h>
@@ -11,7 +11,7 @@
 #include "pen.h"
 #include <kiconloader.h>
 
-Pen::Pen(const char *toolname) : Tool(toolname)
+Pen::Pen(const QString & toolname) : Tool(toolname)
 {
   drawing= FALSE;
   tooltip= i18n("Pen");
@@ -20,7 +20,7 @@ Pen::Pen(const char *toolname) : Tool(toolname)
 
 void Pen::activating()
 {
-  kdDebug(3000) << "Pen::activating() hook called canvas=" << canvas << "\n" << endl;
+  kdDebug(4400) << "Pen::activating() hook called canvas=" << canvas << "\n" << endl;
   drawing= FALSE;
 
   canvas->setCursor(crossCursor);
@@ -33,11 +33,11 @@ void Pen::mousePressEvent(QMouseEvent *e)
   QPainter painter2;
   QWMatrix m;
 
-  kdDebug(3000) << "Pen::mousePressEvent() handler called\n" << endl;
+  kdDebug(4400) << "Pen::mousePressEvent() handler called\n" << endl;
   
   if (isActive()) {
     if (drawing) {
-      kdDebug(3000) << "Pen: Warning button press received while drawing\n" << endl;
+      kdDebug(4400) << "Pen: Warning button press received while drawing\n" << endl;
     }
     x= (e->pos()).x();
     y= (e->pos()).y();
@@ -72,7 +72,7 @@ void Pen::mousePressEvent(QMouseEvent *e)
     drawing= TRUE;
   } 
   if (!isActive()) {
-    kdWarning(3000) << "Warning event received when inactive (ignoring)\n" << endl;
+    kdWarning(4400) << "Warning event received when inactive (ignoring)\n" << endl;
   }
 }
 
@@ -90,7 +90,7 @@ void Pen::mouseMoveEvent(QMouseEvent *e)
 
     if (drawing) {
       if ((x != lastx) || (y != lasty)) {
-	emit modified();
+	canvas->markModified();
 	m.scale((float) 100/(canvas->zoom()), (float) 100/(canvas->zoom()));
 
 	painter1.begin(canvas->pixmap());
@@ -122,17 +122,17 @@ void Pen::mouseMoveEvent(QMouseEvent *e)
     }
   }
   else {
-    kdWarning(3000) << "Warning event received when inactive (ignoring)\n" << endl;
+    kdWarning(4400) << "Warning event received when inactive (ignoring)\n" << endl;
   }
 }
 
 void Pen::mouseReleaseEvent(QMouseEvent *e)
 {
-  kdDebug(3000) << "Pen::mouseReleaseEvent() handler called\n" << endl;
+  kdDebug(4400) << "Pen::mouseReleaseEvent() handler called\n" << endl;
   if (isActive() && (e->button() == activeButton) && drawing)
     drawing= FALSE;
   if (!isActive()) {
-    kdWarning(3000) << "Warning event received when inactive (ignoring)\n" << endl;
+    kdWarning(4400) << "Warning event received when inactive (ignoring)\n" << endl;
   }
 }
 
