@@ -10,7 +10,7 @@ class Rectangle : public Tool
 {
   Q_OBJECT
 public:
-  Rectangle(const char *toolname);
+  Rectangle(const QString & toolname);
   void mousePressEvent(QMouseEvent *e);
   void mouseMoveEvent(QMouseEvent *e);
   void mouseReleaseEvent(QMouseEvent *e);
