@@ -1,4 +1,4 @@
-// $Id: statusbar.h,v 1.1 1997/05/19 13:42:57 kulow Exp $
+// $Id: statusbar.h,v 1.3 2000/11/23 18:00:33 lukas Exp $
 
 #ifndef STATUSBAR_H
 #define STATUSBAR_H
@@ -12,7 +12,7 @@ public:
   StatusBar(QWidget *parent= 0, const char *name= 0);
 
   // public slots:
-  void setMessage(const char *message);
+  void setMessage(const QString & message);
 
 
 protected:
