@@ -1,14 +1,17 @@
 
 #include "text.moc"
 
-#include <qpainter.h>
-#include <qkeycode.h>
-#include <kiconloader.h>
 #include <stdlib.h>
 
-#define TIMER_INTERVALL 500
-#define CURSOR_WIDTH 9 // has to be odd number
-#define CURSOR_HEIGHT 15
+#include <qpainter.h>
+#include <qkeycode.h>
+
+#include <kiconloader.h>
+#include <kdebug.h>
+
+static const int TIMER_INTERVALL = 500;
+static const int CURSOR_WIDTH = 9; // has to be odd number
+static const int CURSOR_HEIGHT = 15;
 
 Text::Text()
   : Tool(),
@@ -21,7 +24,7 @@ Text::Text()
   lineStack.setAutoDelete(true);  
 }
 
-Text::Text(const char *toolname)
+Text::Text(const QString & toolname)
   : Tool(toolname),
     startx(0), // starty(0),
     cursorH(CURSOR_HEIGHT),
@@ -57,13 +60,13 @@ Text::mouseReleaseEvent(QMouseEvent *e)
     charBuffer = "";
     startx = lastx = e->x();
     starty = lasty = e->y();
-    //    debug("linestack count %i",lineStack.count());
+    //    kdDebug() << "linestack count " << lineStack.count() << endl;
     // clear stack
     while ((i=lineStack.pop()) != NULL)
       delete i;
-    //    debug("linestack count %i",lineStack.count());
+    //    kdDebug() << "linestack count " << lineStack.count() << endl;
     // here paint a blinking textmarker
-    //    debug("text enabled");
+    //    kdDebug() << "text enabled" << endl;
     cursorH = canvas->fontMetrics().ascent();
     cursorW = (cursorH/2)+1;
     paintC();
@@ -82,7 +85,7 @@ Text::keyPressEvent(QKeyEvent *e)
   paint.begin(canvas->zoomedPixmap());
 
   int key = e->key();
-  //  debug("keycode %i",key);
+  //  kdDebug() << "keycode " << key << endl;
   if ( Key_Return == key || Key_Enter == key ) { //  "return" 
     if (showingC) {
       paintC(&paint);
@@ -110,7 +113,7 @@ Text::keyPressEvent(QKeyEvent *e)
       paintC(&paint);
     }
     lastc = charBuffer.at(charBuffer.length()-1);
-    debug("remove %c", (char)lastc);
+    kdDebug() << "remove " << (char)lastc << endl;
     if (lastc == '\n') {
       charBuffer.remove(charBuffer.length()-1,1);
       // goto previous line
@@ -229,6 +232,6 @@ Text::paintBuffer()
     paint.end();
     canvas->updateZoomed();
     canvas->repaint(r);    
-    emit modified();
+    canvas->markModified();
   }
 }
