@@ -1,4 +1,4 @@
-// $Id: tool.cpp,v 1.12 2000/06/05 11:04:59 hoelzer Exp $
+// $Id: tool.cpp,v 1.14 2000/11/25 10:06:51 mlaurent Exp $
 
 #include <kdebug.h>
 #include <stdio.h>
@@ -11,16 +11,14 @@ Tool::Tool()
   active= false;
   canvas= 0;
   props= 0;
-  tooltip= 0;
 }
 
-Tool::Tool(const char *toolname)
+Tool::Tool(const QString & toolname)
   : name(toolname)
 {
-  active= false;
-  canvas= 0;
-  props= 0;
-  tooltip= 0;
+  active = false;
+  canvas = 0;
+  props = 0;
 }
 
 
@@ -52,25 +50,25 @@ bool Tool::isActive()
 
 void Tool::setLeftPen(QPen &p)
 {
-  kdDebug(3000) << "Tool::setLeftPen()\n" << endl;
+  kdDebug(4400) << "Tool::setLeftPen()" << endl;
   leftpen= p;
 }
 
 void Tool::setLeftBrush(QBrush &b)
 {
-  kdDebug(3000) << "Tool::setLeftBrush()\n" << endl;
+  kdDebug(4400) << "Tool::setLeftBrush()" << endl;
   leftbrush= b;
 }
 
 void Tool::setRightPen(QPen &p)
 {
-  kdDebug(3000) << "Tool::setRightPen()\n" << endl;
+  kdDebug(4400) << "Tool::setRightPen()" << endl;
   rightpen= p;
 }
 
 void Tool::setRightBrush(QBrush &b)
 {
-  kdDebug(3000) << "Tool::setRightBrush()\n" << endl;
+  kdDebug(4400) << "Tool::setRightBrush()" << endl;
   rightbrush= b;
 }
 
