@@ -6,22 +6,22 @@
 #include <qwidget.h>
 
 class QScrollView;
-class SideBar;
+
 
 /**
  * @author Richard Moore rich@kde.org
  */
 class View : public QWidget {
-  Q_OBJECT
+    Q_OBJECT
+
 public:
-  View(QWidget *parent, const char *name);
-  ~View();
+    View(QWidget *parent, const char *name);
+    ~View();
 
-  void resizeEvent(QResizeEvent *);
-  void updateRects();
+    void resizeEvent(QResizeEvent *);
+    void updateRects();
 
-  QScrollView *c;
-  SideBar *s;
+    QScrollView *c;
 };
 
 #endif // VIEW_H
