@@ -74,7 +74,7 @@ void KPBitmapList::slotSelected(int index)
 
 void KPBitmapList::saveCurrentBitmap()
 {
-    QString fileStr = QFileDialog::getSaveFileName(QString::null,
+    QString fileStr = KFileDialog::getSaveFileName(QString::null,
                                                    i18n("X Bitmap (*.xbm)"));
     if(!fileStr.isEmpty()){
         QApplication::setOverrideCursor(waitCursor);
@@ -88,7 +88,7 @@ void KPBitmapList::saveCurrentBitmap()
 
 void KPBitmapList::saveCHeader()
 {
-    QString fileStr = QFileDialog::getSaveFileName(QString::null,
+    QString fileStr = KFileDialog::getSaveFileName(QString::null,
                                                    i18n("C++ Header (*.h)"));
     if(!fileStr.isEmpty()){
         QFile file(fileStr);
@@ -127,7 +127,7 @@ void KPBitmapList::saveCHeader()
 
 void KPBitmapList::savePointArray()
 {
-    QString fileStr = QFileDialog::getSaveFileName(QString::null,
+    QString fileStr = KFileDialog::getSaveFileName(QString::null,
                                                    i18n("C++ Header (*.h)"));
     if(fileStr.isEmpty())
         return;
@@ -176,7 +176,7 @@ void KPBitmapList::savePointArray()
                     
 void KPBitmapList::saveAll()
 {
-    QString dirStr = QFileDialog::getExistingDirectory();
+    QString dirStr = KFileDialog::getExistingDirectory();
     unsigned int totalFiles = bmpList.count();
     if(!dirStr.isNull() && count() != 0){
         unsigned int i;
@@ -199,7 +199,7 @@ void KPBitmapList::saveAll()
 
 void KPBitmapList::load()
 {
-    loadFile(QFileDialog::getOpenFileName());
+    loadFile(KFileDialog::getOpenFileName());
 }
 
 void KPBitmapList::loadFile(const QString &fileStr)
