@@ -20,6 +20,7 @@
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <klineedit.h>
+#include <knotifyclient.h>
 
 #include <stdlib.h>
 
@@ -30,6 +31,7 @@
 
 KSnapshot::KSnapshot(QWidget *parent, const char *name)
   : KSnapshotBase(parent, name)
+  , DCOPObject("interface")
 {
 
     grabber = new QWidget( 0, 0, WStyle_Customize | WX11BypassWM );
@@ -50,6 +52,7 @@ KSnapshot::KSnapshot(QWidget *parent, const char *name)
 
     connect( &grabTimer, SIGNAL( timeout() ), this, SLOT(  grabTimerDone() ) );
     urlRequester->setURL( QDir::currentDirPath() + "/" + i18n("snapshot") + "1.png" );
+    urlRequester->fileDialog()->setKeepLocation(true);
 
     // Make sure the name is not already being used
     QFileInfo fi( urlRequester->url());
@@ -201,7 +204,7 @@ void KSnapshot::updatePreview()
 void KSnapshot::grabTimerDone()
 {
     performGrab();
-    QApplication::beep();
+    KNotifyClient::beep(i18n("The screen has been successfully grabbed."));
 }
 
 void KSnapshot::performGrab()
@@ -225,4 +228,23 @@ void KSnapshot::performGrab()
     show();
 }
 
+void KSnapshot::setTime(int newTime)
+{
+        delaySpin->setValue(newTime);
+}
+
+void KSnapshot::setURL(QString newURL)
+{
+        urlRequester->setURL( newURL );
+}
+
+void KSnapshot::setGrabPointer(bool grab)
+{
+        onlyWindow->setChecked( grab );
+}
+
+void KSnapshot::exit()
+{
+        this->reject();
+}
 #include "ksnapshot.moc"
