@@ -75,6 +75,12 @@ protected slots:
   virtual void keyPressEvent( QKeyEvent *ev );
 // removed resizeEvent...
 
+  void slotPopupMenu( const QPoint &pos );
+
+  void slotSaveImageAs();
+
+  void slotResultSaveImageAs( KIO::Job *job );
+
 private:
   KIO::SimpleJob * m_job;
   KViewKonqExtension * m_extension;
@@ -86,6 +92,9 @@ private:
   KAction *m_paZoomOut;
   KAction *m_paRotate;
   KAction *m_paReset;
+
+  QString m_popupDoc;
+  QString m_mimeType;
 };
 
 class KViewKonqExtension: public KParts::BrowserExtension
