@@ -14,6 +14,9 @@
 #include <khelpmenu.h>
 #include <kedittoolbar.h>
 
+#include <stdlib.h>
+#include <unistd.h>
+
 #include "kviewpart.h"
 #include "kviewshell.moc"
 
@@ -38,7 +41,7 @@ KViewShell::KViewShell(QString partname, KAboutData *about)
   else
     {
       KMessageBox::error(this, "No libkviewerpart found !");
-      exit(-1);
+      ::exit(-1);
     }
 
   setCentralWidget(view->widget());
