@@ -5,28 +5,30 @@
 #include <kaboutdata.h>
 #include <qdir.h>
 
+#include <stdlib.h>
 
 #include "kviewshell.h"
 
 
 static KCmdLineOptions options[] =
 {
-  { "+part", "The part to use", 0},
-  { "+file(s)",          "Files to load", 0 },
+  { "+part",    I18N_NOOP("The part to use"), 0},
+  { "+file(s)", I18N_NOOP("Files to load"), 0 },
   { 0,0,0 }
 };
 
 
-static const char *description = "Generic framework for viewer applications.";
+static const char *description = I18N_NOOP("Generic framework for viewer applications.");
 
 
 int main(int argc, char **argv)
 {
-  KAboutData about ("kviewshell", "KViewShell", "0.1",
+  KAboutData about ("kviewshell", I18N_NOOP("KViewShell"), "0.1",
 		    description, KAboutData::License_GPL,
 		    "(C) 2000, Matthias Hoelzer-Kluepfel",
-		    "Displays various document formats. "
-		    "Based on original code from KGhostView.");
+                    0,
+		    I18N_NOOP("Displays various document formats. "
+		    "Based on original code from KGhostView."));
   about.addAuthor ("Matthias Hoelzer-Kluepfel", I18N_NOOP("Framework"),
 		   "mhk@caldera.de");
   about.addAuthor ("David Sweet", 
