@@ -19,7 +19,11 @@
 #else
 #  include <stdio.h>
 #  include <stdlib.h>
-#  include <stdarg.h>
+/*
+   This one creates compilation problems on Solaris. Yes, the bug is Solaris,
+   but it still compiles and works without this #include, so I removed it.
+   #  include <stdarg.h>
+*/
 #  include <string.h>
 #endif
 
