@@ -16,7 +16,7 @@ void KIFDndListBox::dropEvent(QDropEvent *ev)
     if(QUriDrag::decode(ev, fileList)){
         QStrListIterator it(fileList);
         for(;it.current(); ++it){
-            kdWarning() << "In dropEvent for " << it.current() << endl;
+            kdDebug() << "In dropEvent for " << it.current() << endl;
             KURL url(it.current());
             if(!url.isMalformed()){
                 validUrls = true;
