@@ -8,7 +8,9 @@ class KIFDndListBox : public QListBox
     Q_OBJECT
 public:
     KIFDndListBox(QWidget *parent=0, const char *name=0)
-        : QListBox(parent, name){setAcceptDrops(true);}
+        : QListBox(parent, name){
+            setAcceptDrops(true); setSelectionMode(QListBox::Extended);
+        }
 signals:
     void urlDropped(const QString &urlStr);
     void dropFinished();
