@@ -1,12 +1,14 @@
 #ifndef __IMAGELIST_H
 #define __IMAGELIST_H
 
-#include <kmainwindow.h>
+#include <ktmainwindow.h>
+#include <kaccel.h>
 #include "imagewindow.h"
-class KIFDndListBox;
+#include "dndlistbox.h"
 class QListBoxItem;
+class QTimer;
 
-class KIFImageList : public KMainWindow
+class KIFImageList : public KTMainWindow
 {
     Q_OBJECT
 public:
@@ -48,22 +50,33 @@ protected slots:
     void slotSingleColor();
     void slotGenerateHtml();
     void slotGrab();
+    void slotRotate45();
     void slotPlayAni();
+    void slotSlideShow();
+    void slotSlideShowTimer();
     void slotDropFinished();
     void slotHide();
     void slotShow();
     void slotQuit();
+    void slotSelectAll(){fileList->selectAll(true);}
+    void slotDeselectAll(){fileList->clearSelection();}
 protected:
+    void keyPressEvent(QKeyEvent *ev);
     void closeEvent(QCloseEvent *ev);
     int findURLIndex(const QString &url);
     void loadColorPlugin();
 
     void *(*singleColorDlg)();
     void *(*imageColorDlg)();
+
+    KAccel *keys;
     
     KIFDndListBox *fileList;
     KIFImageWindow *imageWindow;
     bool wasVisible, dlregistered;
+    QTimer *showTimer;
+    QPopupMenu *fileMnu; // needed to change SlideShow entry
+    int slideShowID;
 };
 
 #endif
