@@ -1,5 +1,6 @@
 #include "imagewindow.h"
 #include "ifapp.h"
+#include "imagelist.h"
 #include "bigwindow.h"
 #include <kiconloader.h>
 #include <kglobal.h>
@@ -7,6 +8,7 @@
 #include <kstddirs.h>
 #include <kwin.h>
 #include <kurl.h>
+#include <klocale.h>
 #include <qdragobject.h>
 #include <qwmatrix.h>
 
@@ -37,13 +39,16 @@ KIFImageWindow::KIFImageWindow(QWidget *parent, const char *name)
     : QWidget(parent, name/* ,WResizeNoErase*/)
 {
     setAcceptDrops(true);
+    setFocusPolicy(ClickFocus);
     qWarning("Display depth: %d", QPixmap::defaultDepth());
     bigBitWindow = NULL;
     KConfig *config = KGlobal::config();
     config->setGroup("ImageWindow");
     cache16bpp = config->readBoolEntry("Promote16bpp", true);
     inMouseMove = false;
+    maxpect = false; // hack to avoid trying to maxpect until framed
     slotSetFile(KGlobal::dirs()->findResource("appdata", "logo.png"));
+    drawLogoText();
 
     connect(kifapp(), SIGNAL(hideAllWindows()), this, SLOT(slotHide()));
     connect(kifapp(), SIGNAL(showAllWindows()), this, SLOT(slotShow()));
@@ -52,8 +57,38 @@ KIFImageWindow::KIFImageWindow(QWidget *parent, const char *name)
     setBackgroundMode(NoBackground);
     pixImage.setAlphaBuffer(true);
     scaleImage.setAlphaBuffer(true);
+    show();
+    // calculate window frame & titlebar size. Logo is 340x226.
+    KWin::Info info = KWin::info(winId());
+    QRect fR = info.frameGeometry;
+    frameW = fR.width()-340;
+    frameH = fR.height()-226;
+    qWarning("Frame: %dx%d", frameW, frameH);
+    maxpect = true;
 }
 
+void KIFImageWindow::drawLogoText()
+{
+    QPainter p(&pix);
+    QFont f = font();
+    f.setBold(true);
+    f.setPointSize(12);
+    p.setFont(f);
+    int i = QFontMetrics(f).height()+1;
+    p.drawText(142, 20, i18n("(C)Daniel M. Duley"));
+    p.drawText(142, 20+i, i18n("<mosfet@mandrakesoft.com>"));
+    p.drawText(142, 20+i*2, i18n("<mosfet@kde.org>"));
+    p.drawText(142, 20+i*3, i18n("Logo by <kris@animexx.de>"));
+    p.drawText(150, 25+i*4, i18n("Mouse controls:"));
+    p.drawText(150, 25+i*5, i18n("Left: Select Area"));
+    p.drawText(150, 25+i*6, i18n("Middle: Lookup color"));
+    p.drawText(150, 25+i*7, i18n("Right: Menu/Controls"));
+    p.drawText(150, 25+i*8, i18n("Dbl Click: Unselect"));
+
+    p.end();
+}
+
+
 QImage* KIFImageWindow::image()
 {
 
@@ -92,14 +127,52 @@ void KIFImageWindow::slotSetSelection(const QRect &r)
     repaint(selRect);
 }
 
-void KIFImageWindow::slotUpdateFromImage()
+
+void KIFImageWindow::resizeWithMaxpect()
 {
-    pix.convertFromImage(pixImage);
+    if(!maxpect){
+        resize(pix.size());
+        return;
+    }
     if(pix.width() != width() || pix.height() != height()){
-        resize(pix.width(), pix.height());
+        QRect deskRect = QApplication::desktop()->rect();
+        deskRect.setWidth(deskRect.width()-frameW-10);
+        deskRect.setHeight(deskRect.height()-frameH-10);
+        QRect r = QRect(x(), y(), pix.width(), pix.height());
+        // may need to do this twice
+        if(r.width() > deskRect.width() || r.height() > deskRect.height()){
+            while(r.width() > deskRect.width() || r.height() > deskRect.height()){
+                if(r.width() > deskRect.width()){
+                    float percent = ((float)deskRect.width())/r.width();
+                    r.setWidth((int)r.width()*percent);
+                    r.setHeight((int)r.height()*percent);
+                    qWarning("Scaling width");
+                }
+                if(r.height() > deskRect.height()){
+                    float percent = ((float)deskRect.height())/r.height();
+                    r.setWidth((int)r.width()*percent);
+                    r.setHeight((int)r.height()*percent);
+                    qWarning("Scaling height");
+                }
+            }
+            // reposition if needed
+            if(r.bottom() > deskRect.bottom())
+                r.setTop(deskRect.top());
+            if(r.right() > deskRect.right())
+                r.setLeft(deskRect.left());
+        }
+        resize(r.size());
     }
     else
         repaint(false);
+}
+
+
+
+void KIFImageWindow::slotUpdateFromImage()
+{
+    pix.convertFromImage(pixImage);
+    resizeWithMaxpect();
     if(bigBitWindow)
         bigBitWindow->slotSetPixmap(pix);
 }
@@ -110,10 +183,7 @@ void KIFImageWindow::slotUpdatePixmap()
     scaleImage.reset();
     selRect.setWidth(0);
     emit selectionChanged(selRect);
-    if(pix.width() != width() || pix.height() != height())
-        resize(pix.width(), pix.height());
-    else
-        repaint(false);
+    resizeWithMaxpect();
 }
 
 void KIFImageWindow::slotSetFile(const QString &fileStr)
@@ -145,17 +215,14 @@ void KIFImageWindow::slotSetFile(const QString &fileStr)
 
     if(pix.isNull()){
         pix.load(KGlobal::dirs()->findResource("appdata", "logo.png"));
+        drawLogoText();
         emit invalidFile();
     }
-    if(pix.width() != width() || pix.height() != height())
-        resize(pix.width(), pix.height());
-    else
-        repaint(false);
     if(bigBitWindow)
         bigBitWindow->slotSetPixmap(pix);
     emit selectionChanged(selRect);
     QApplication::restoreOverrideCursor();
-    positionAndMaxpect();
+    resizeWithMaxpect();
 }
 
 void KIFImageWindow::resizeEvent(QResizeEvent *ev)
@@ -183,7 +250,7 @@ void KIFImageWindow::paintEvent(QPaintEvent *ev)
     if(pix.mask()){
         QPainter p;
         p.begin(this);
-        p.fillRect(r, Qt::blue);
+        p.fillRect(r, Qt::black);
         p.end();
     }
     bitBlt(this, r.topLeft(), &pix, r, Qt::CopyROP);
@@ -332,36 +399,6 @@ void KIFImageWindow::slotShow()
         show();
 }
 
-void KIFImageWindow::positionAndMaxpect()
-{
-    QRect deskRect = QApplication::desktop()->rect();
-    QRect r = rect();
-    bool needUpdate = false;
-
-    // could need to scale opposite orient again after first scaling
-    while(r.bottom() > deskRect.bottom() || r.right() > deskRect.right()){
-        needUpdate = true;
-        r.setX(deskRect.x());
-        r.setY(deskRect.y());
-        if(r.width() > deskRect.width()){
-            float percent = ((float)deskRect.width())/r.width();
-            r.setWidth((int)r.width()*percent);
-            r.setHeight((int)r.height()*percent);
-            qWarning("Scaling width");
-        }
-        else{
-            float percent = ((float)deskRect.height())/r.height();
-            r.setWidth((int)r.width()*percent);
-            r.setHeight((int)r.height()*percent);
-            qWarning("Scaling height");
-        }
-    }
-    if(needUpdate){
-        qWarning("Maxpecting");
-        move(r.topLeft());
-        resize(r.size());
-    }
-}
 
 
 
