@@ -24,15 +24,15 @@ MovieWindow::MovieWindow(const QString &fileName, QWidget *parent,
 
 QSize MovieWindow::sizeHint() const
 {
-    warning("In sizeHint()");
-    warning("sizeHint: %d, %d", movie->framePixmap().size().width(),
+    qWarning("In sizeHint()");
+    qWarning("sizeHint: %d, %d", movie->framePixmap().size().width(),
             movie->framePixmap().size().height());
     return(movie->framePixmap().size());
 }
 
 void MovieWindow::closeEvent(QCloseEvent *)
 {
-    warning("In ani close event");
+    qWarning("In ani close event");
     delete movie;
     delete this;
 }
