@@ -1,7 +1,7 @@
 #ifndef __BINDINGS_H
 #define __BINDINGS_H
 
-#include <magick/magick.h>
+#include <mini-magick/magick.h>
 
 extern "C"{
     extern Export void runMagickProgressDlg(const char *, const off_t, const off_t);
