@@ -80,7 +80,7 @@ protected:
     KIFDirTree *tree;
     QLineEdit *pathEdit;
     QString pathStr, tmpStr;
-    QDir::SortSpec sorting;
+    int sorting;
     KIFThumbView::IconSize iconSize;
     bool previewStat, dupFirst;
     QIconViewItem *rightClickItem;
